/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnInit } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ContextService } from '../common/provider.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI TreeList column-menu item for resizing all columns to fit the widest header or cell content without wrapping. [See example](slug:columnmenu_treelist#toc-autosize-all-columns-item).
 *
 * Place this component inside a [`ColumnMenuTemplate`]({% slug api_treelist_columnmenutemplatedirective %}) directive to enable the feature.
 * Register the component as a known column menu item by setting the [`ColumnMenuService`]({% slug api_treelist_columnmenuservice %}) to the `service` input. [See example](slug:columnmenu_treelist#toc-customizing-the-content).
 *
 * @example
 * ```html
 * <kendo-treelist [columnMenu]="true" ...>
 *   <ng-template kendoTreeListColumnMenuTemplate let-service="service">
 *     <kendo-treelist-columnmenu-autosize-all-columns [service]="service">
 *     </kendo-treelist-columnmenu-autosize-all-columns>
 *   </ng-template>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuAutoSizeAllColumnsComponent extends ColumnMenuItemBase implements OnInit {
    ctx: ContextService;
    displayInlineFlexIcon: SVGIcon;
    constructor(ctx: ContextService);
    ngOnInit(): void;
    /**
     * Resizes all columns to the minimum possible width so that they fit the widest header or cell content without wrapping.
     */
    autoSizeAllColumns(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuAutoSizeAllColumnsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuAutoSizeAllColumnsComponent, "kendo-treelist-columnmenu-autosize-all-columns", never, {}, {}, never, never, true, never>;
}
