/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnInit } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ContextService } from '../common/provider.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI for Angular TreeList column-menu item for resizing a specified column to fit the header or cell content without wrapping. [See example](slug:columnmenu_treelist#toc-customizing-the-content).
 *
 * Place this component inside a [`ColumnMenuTemplate`]({% slug api_treelist_columnmenutemplatedirective %}) directive to enable the feature.
 * Set the [`ColumnMenuService`]({% slug api_treelist_columnmenuservice %}) and `column` inputs using the values passed by the template.
 *
 * @example
 * ```html
 * <kendo-treelist [columnMenu]="true" ...>
 *   <ng-template kendoTreeListColumnMenuTemplate let-service="service" let-column="column">
 *     <kendo-treelist-columnmenu-autosize-column [column]="column" [service]="service">
 *     </kendo-treelist-columnmenu-autosize-column>
 *   </ng-template>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuAutoSizeColumnComponent extends ColumnMenuItemBase implements OnInit {
    ctx: ContextService;
    /**
     * The TreeList column instance to resize with the auto size column option.
     */
    column: any;
    maxWidthIcon: SVGIcon;
    constructor(ctx: ContextService);
    ngOnInit(): void;
    /**
     * Resizes the specified column to the minimum possible width so that it fits the widest header or cell content without wrapping.
     */
    autoSizeColumn(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuAutoSizeColumnComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuAutoSizeColumnComponent, "kendo-treelist-columnmenu-autosize-column", never, { "column": { "alias": "column"; "required": false; }; }, {}, never, never, true, never>;
}
