/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ChangeDetectorRef, ElementRef } from '@angular/core';
import { ColumnInfoService } from '../common/column-info.service';
import { LocalizationService } from "@progress/kendo-angular-l10n";
import { ColumnMenuItemBase } from './column-menu-item-base';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 *
 * Represents the Kendo UI for Angular TreeList column-menu item for chaging the visibility of the columns. [See example](slug:columnmenu_treelist#toc-column-chooser-item).
 *
 * Place this component inside a [`ColumnMenuTemplate`]({% slug api_treelist_columnmenutemplatedirective %}) directive to enable the feature.
 * Set the [`ColumnMenuService`]({% slug api_treelist_columnmenuservice %}) and `column` inputs using the values passed by the template.
 *
 * @example
 * ```html
 * <kendo-treelist [columnMenu]="true" ...>
 *   <ng-template kendoTreeListColumnMenuTemplate let-service="service" let-column="column">
 *     <kendo-treelist-columnmenu-chooser [column]="column" [service]="service">
 *     </kendo-treelist-columnmenu-chooser>
 *   </ng-template>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuChooserComponent extends ColumnMenuItemBase {
    localization: LocalizationService;
    private columnInfoService;
    private changeDetector;
    private hostElement;
    /**
     * Fires when the content expands.
     */
    expand: EventEmitter<any>;
    /**
     * Fires when the content collapses.
     */
    collapse: EventEmitter<any>;
    /**
     * Specifies if the content is expanded.
     * @default false
     */
    expanded: boolean;
    /**
     * @hidden
     */
    isLast: boolean;
    /**
     * @hidden
     */
    actionsClass: string;
    get columns(): any;
    columnsIcon: SVGIcon;
    constructor(localization: LocalizationService, columnInfoService: ColumnInfoService, changeDetector: ChangeDetectorRef, hostElement: ElementRef);
    /**
     * @hidden
     */
    onApply(changed: any[]): void;
    /**
     * @hidden
     */
    onCollapse(): void;
    /**
     * @hidden
     */
    onExpand(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuChooserComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuChooserComponent, "kendo-treelist-columnmenu-chooser", never, { "expanded": { "alias": "expanded"; "required": false; }; "isLast": { "alias": "isLast"; "required": false; }; }, { "expand": "expand"; "collapse": "collapse"; }, never, never, true, never>;
}
