/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef } from '@angular/core';
import { LocalizationService } from "@progress/kendo-angular-l10n";
import { ColumnMenuItemBase } from './column-menu-item-base';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * Represents the column-menu item for editing column filters in the TreeList.
 *
 * Render this component inside a [`ColumnMenuTemplate`]({% slug api_treelist_columnmenutemplatedirective %}) directive.
 *
 * To register the component as a known column menu item, set the [`ColumnMenuService`]({% slug api_treelist_columnmenuservice %})
 * that the template passes to the `service` input of the `kendo-treelist-columnmenu-filter` component.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *  <kendo-treelist-column field="ProductName">
 *   <ng-template kendoTreeListColumnMenuTemplate>
 *    <kendo-treelist-columnmenu-filter></kendo-treelist-columnmenu-filter>
 *   </ng-template>
 *  </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuFilterComponent extends ColumnMenuItemBase {
    localization: LocalizationService;
    private hostElement;
    /**
     * Fires when the content expands.
     */
    expand: EventEmitter<any>;
    /**
     * Fires when the content collapses.
     */
    collapse: EventEmitter<any>;
    /**
     * Specifies if the content is expanded.
     * @default false
     */
    expanded: boolean;
    /**
     * @hidden
     */
    isLast: boolean;
    /**
     * @hidden
     */
    actionsClass: string;
    filterIcon: SVGIcon;
    constructor(localization: LocalizationService, hostElement: ElementRef);
    /**
     * @hidden
     */
    onCollapse(): void;
    /**
     * @hidden
     */
    onExpand(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuFilterComponent, "kendo-treelist-columnmenu-filter", never, { "expanded": { "alias": "expanded"; "required": false; }; "isLast": { "alias": "isLast"; "required": false; }; }, { "expand": "expand"; "collapse": "collapse"; }, never, never, true, never>;
}
