/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the content template for the [`kendo-treelist-columnmenu-item`]({% slug api_treelist_columnmenuitemcomponent %}) component.
 * Use this directive to specify the content of a column menu item.
 * To define the content template, nest an `<ng-template>` tag with the `kendoTreeListColumnMenuItemContentTemplate` directive inside a `<kendo-treelist-columnmenu-item>`.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column field="ProductName">
 *     <ng-template kendoTreeListColumnMenuTemplate>
 *       <kendo-treelist-columnmenu-item text="Item Text" [expanded]="true">
 *         <ng-template kendoTreeListColumnMenuItemContentTemplate>
 *           Item Content
 *         </ng-template>
 *       </kendo-treelist-columnmenu-item>
 *     </ng-template>
 *   </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuItemContentTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuItemContentTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ColumnMenuItemContentTemplateDirective, "[kendoTreeListColumnMenuItemContentTemplate]", never, {}, {}, never, never, true, never>;
}
