/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, OnChanges, AfterViewInit } from '@angular/core';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ColumnMenuItemContentTemplateDirective } from './column-menu-item-content-template.directive';
import { ColumnMenuService } from './column-menu.service';
import * as i0 from "@angular/core";
/**
 * Represents an item you can place inside a [`ColumnMenuTemplate`]({% slug api_treelist_columnmenutemplatedirective %}) directive.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <ng-template kendoTreeListColumnMenuTemplate let-service="service" let-column="column">
 *     <kendo-treelist-columnmenu-item text="Fit column"></kendo-treelist-columnmenu-item>
 *   </ng-template>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuItemComponent implements AfterViewInit, OnChanges {
    /**
     * Fires when the item is clicked.
     */
    itemClick: EventEmitter<any>;
    /**
     * Fires when the content expands.
     */
    expand: EventEmitter<any>;
    /**
     * Fires when the content collapses.
     */
    collapse: EventEmitter<any>;
    /**
     * Sets the name of the [font icon](slug:icons#icons-list) rendered for the item.
     */
    icon: string;
    /**
     * Sets the name of the [SVG icon]({% slug svgicon_list %}) rendered for the item.
     */
    svgIcon: SVGIcon;
    /**
     * Sets the item text.
     */
    text: string;
    /**
     * Specifies if the item is selected.
     */
    selected: boolean;
    /**
     * Specifies if the item is disabled.
     */
    disabled: boolean;
    /**
     * Specifies if the item is expanded.
     */
    expanded: boolean;
    /**
     * Provides the [ColumnMenuService]({% slug api_treelist_columnmenuservice %}) instance.
     * Required to include the item in the column menu keyboard navigation sequence.
     */
    service: ColumnMenuService;
    contentTemplate: ColumnMenuItemContentTemplateDirective;
    contentState: string;
    contentId: string;
    chevronUpIcon: SVGIcon;
    chevronDownIcon: SVGIcon;
    get expandedIcon(): string;
    get expandedSvgIcon(): SVGIcon;
    ngAfterViewInit(): void;
    ngOnChanges(changes: any): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    private updateContentState;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuItemComponent, "kendo-treelist-columnmenu-item", never, { "icon": { "alias": "icon"; "required": false; }; "svgIcon": { "alias": "svgIcon"; "required": false; }; "text": { "alias": "text"; "required": false; }; "selected": { "alias": "selected"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "expanded": { "alias": "expanded"; "required": false; }; "service": { "alias": "service"; "required": false; }; }, { "itemClick": "itemClick"; "expand": "expand"; "collapse": "collapse"; }, ["contentTemplate"], never, true, never>;
}
