/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from "@progress/kendo-angular-l10n";
import { ColumnInfoService } from '../common/column-info.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * Represents the column-menu item that lets you lock or unlock columns.
 *
 * Render this component inside a [`ColumnMenuTemplate`]({% slug api_treelist_columnmenutemplatedirective %}) directive.
 *
 * To register the component as a known column menu item, set the [`ColumnMenuService`]({% slug api_treelist_columnmenuservice %})
 * that the template passes to the `service` input of the `kendo-treelist-columnmenu-lock` component.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column field="ProductName">
 *     <ng-template kendoTreeListColumnMenuTemplate>
 *       <kendo-treelist-columnmenu-lock></kendo-treelist-columnmenu-lock>
 *     </ng-template>
 *   </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuLockComponent extends ColumnMenuItemBase {
    private localization;
    private columnInfoService;
    private changeDetector;
    unlockIcon: SVGIcon;
    lockIcon: SVGIcon;
    constructor(localization: LocalizationService, columnInfoService: ColumnInfoService, changeDetector: ChangeDetectorRef);
    get text(): string;
    get icon(): string;
    get svgIcon(): SVGIcon;
    get disabled(): boolean;
    /**
     * @hidden
     */
    toggleColumn(): void;
    private toggleHierarchy;
    private get locked();
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuLockComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuLockComponent, "kendo-treelist-columnmenu-lock", never, {}, {}, never, never, true, never>;
}
