/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { LocalizationService } from "@progress/kendo-angular-l10n";
import { SortService } from '../common/sort.service';
import { ColumnMenuItemBase } from './column-menu-item-base';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * Represents the column-menu item for sorting TreeList columns.
 *
 * Render this component inside a [`ColumnMenuTemplate`]({% slug api_treelist_columnmenutemplatedirective %}) directive.
 *
 * To register the component as a known column menu item, set the [`ColumnMenuService`]({% slug api_treelist_columnmenuservice %})
 * that the template passes to the `service` input of the `kendo-treelist-columnmenu-sort` component.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column field="ProductName">
 *     <ng-template kendoTreeListColumnMenuTemplate>
 *       <kendo-treelist-columnmenu-sort></kendo-treelist-columnmenu-sort>
 *     </ng-template>
 *   </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuSortComponent extends ColumnMenuItemBase {
    localization: LocalizationService;
    protected sortService: SortService;
    sortAscSmallIcon: SVGIcon;
    sortDescSmallIcon: SVGIcon;
    constructor(localization: LocalizationService, sortService: SortService);
    get sortedAsc(): boolean;
    get sortedDesc(): boolean;
    /**
     * @hidden
     */
    toggleSort(dir: string): void;
    private get descriptor();
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuSortComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnMenuSortComponent, "kendo-treelist-columnmenu-sort", never, {}, {}, never, never, true, never>;
}
