/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the template for the column menu in the TreeList. Use this directive to customize the content of the column menu for all or specific columns.
 * To define the content template, nest an `<ng-template>` tag with the `kendoTreeListColumnMenuTemplate` directive inside the `kendo-treelist` or the `<kendo-treelist-column>` component.
 *
 * The template context is passed through the following fields:
 * - `service`&mdash;Represents the [ColumnMenuService]({% slug api_treelist_columnmenuservice %}).
 * - `column`&mdash;Represents the TreeList column.
 *
 * @example
 * ```html
 * <kendo-treelist ... >
 *   <ng-template kendoTreeListColumnMenuTemplate let-service="service">
 *     <kendo-treelist-columnmenu-sort [service]="service">
 *     </kendo-treelist-columnmenu-sort>
 *   </ng-template>
 *   <kendo-treelist-column field="name">
 *     <ng-template kendoTreeListColumnMenuTemplate let-service="service">
 *       <kendo-treelist-columnmenu-sort [service]="service">
 *       </kendo-treelist-columnmenu-sort>
 *     </ng-template>
 *   </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnMenuTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnMenuTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ColumnMenuTemplateDirective, "[kendoTreeListColumnMenuTemplate]", never, {}, {}, never, never, true, never>;
}
