/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { ColumnBase } from './column-base';
import { CellTemplateDirective } from '../rendering/cell-template.directive';
import * as i0 from "@angular/core";
/**
 * Represents the checkbox column for selecting rows in the TreeList. [See example](slug:treelist_row_selection#toc-select-all-checkbox).
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-checkbox-column
 *     [showSelectAll]="true"
 *     [checkChildren]="true"
 *     [expandable]="true">
 *   </kendo-treelist-checkbox-column>
 *   <kendo-treelist-column field="ProductName" title="Product Name"></kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class CheckboxColumnComponent extends ColumnBase {
    parent?: ColumnBase;
    /**
     * Specifies if a select-all checkbox appears in the header.
     */
    showSelectAll: boolean;
    /**
     * Specifies if clicking the checkbox selects or deselects all children.
     */
    checkChildren: boolean;
    /**
     * Specifies if the expanded indicator appears in the column.
     * @default false
     */
    expandable: boolean;
    readonly isCheckboxColumn: boolean;
    template: CellTemplateDirective;
    constructor(parent?: ColumnBase);
    get templateRef(): TemplateRef<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CheckboxColumnComponent, [{ optional: true; host: true; skipSelf: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CheckboxColumnComponent, "kendo-treelist-checkbox-column", never, { "showSelectAll": { "alias": "showSelectAll"; "required": false; }; "checkChildren": { "alias": "checkChildren"; "required": false; }; "expandable": { "alias": "expandable"; "required": false; }; }, {}, ["template"], never, true, never>;
}
