/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { QueryList } from '@angular/core';
import { ColumnBase } from './column-base';
import { OptionChangesService } from '../common/option-changes.service';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare function isColumnGroupComponent(column: any): column is ColumnGroupComponent;
/**
 * Represents the column group header of the TreeList. ([More information and examples]({% slug multicolumnheaders_columns_treelist %})).
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column-group title="File Info">
 *     <kendo-treelist-column field="type" title="Type"> </kendo-treelist-column>
 *     <kendo-treelist-column field="size" title="Size"> </kendo-treelist-column>
 *   </kendo-treelist-column-group>
 * </kendo-treelist>
 * ```
 */
export declare class ColumnGroupComponent extends ColumnBase {
    /**
     * @hidden
     */
    includeInChooser: boolean;
    /**
     * @hidden
     */
    isColumnGroup: boolean;
    /**
     * @hidden
     */
    minResizableWidth: number;
    /**
     * @hidden
     */
    children: QueryList<ColumnBase>;
    constructor(parent?: ColumnBase, optionChanges?: OptionChangesService);
    /**
     * @hidden
     */
    rowspan(): number;
    /**
     * @hidden
     */
    get colspan(): number;
    /**
     * @hidden
     */
    get leafIndex(): number;
    get childrenArray(): any[];
    get hasChildren(): boolean;
    private get firstChild();
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnGroupComponent, [{ optional: true; host: true; skipSelf: true; }, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnGroupComponent, "kendo-treelist-column-group", never, {}, {}, ["children"], never, true, never>;
}
