/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { ColumnBase } from './column-base';
import { CellTemplateDirective } from '../rendering/cell-template.directive';
import { OptionChangesService } from '../common/option-changes.service';
import * as i0 from "@angular/core";
/**
 * Represents the command column of the TreeList. Define the content of the column inside an `<ng-template>` tag.
 * For more information and examples on using the passed fields and command directives, see
 * [editing the TreeList in Angular Reactive Forms]({% slug editing_reactive_forms_treelist %}).
 *
 * Usually, the template contains CRUD command directives such as:
 * - [`EditCommandDirective`]({% slug api_treelist_editcommanddirective %})
 * - [`RemoveCommandDirective`]({% slug api_treelist_removecommanddirective %})
 * - [`CancelCommandDirective`]({% slug api_treelist_cancelcommanddirective %})
 * - [`SaveCommandDirective`]({% slug api_treelist_savecommanddirective %})
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column field="ProductID"></kendo-treelist-column>
 *   <kendo-treelist-command-column title="command">
 *      <ng-template kendoTreeListCellTemplate>
 *         <button kendoTreeListEditCommand class="k-primary">Edit</button>
 *         <button kendoTreeListRemoveCommand>Remove</button>
 *      </ng-template>
 *   </kendo-treelist-command-column>
 * </kendo-treelist>
 * ```
 */
export declare class CommandColumnComponent extends ColumnBase {
    parent?: ColumnBase;
    template: CellTemplateDirective;
    isCommand: boolean;
    constructor(parent?: ColumnBase, optionChanges?: OptionChangesService);
    get templateRef(): TemplateRef<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CommandColumnComponent, [{ optional: true; host: true; skipSelf: true; }, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CommandColumnComponent, "kendo-treelist-command-column", never, {}, {}, ["template"], never, true, never>;
}
