/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Defines the settings for sorting a TreeList column.
 * Use this type to configure sorting options such as allowing unsort and setting the initial direction.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column field="ProductName" [sortable]="{ allowUnsort: true, initialDirection: 'asc'}">
 *   </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export type ColumnSortSettings = boolean | {
    /**
     * Enables the removal of the column sorting.
     */
    allowUnsort?: boolean;
    /**
     * Sets the initial sort direction when changing from unsorted to sorted state.
     */
    initialDirection?: 'asc' | 'desc';
};
/**
 * Specifies a modifier key for multiple column sorting.
 *
 */
export type ModifierKey = 'none' | 'ctrl' | 'shift' | 'alt';
/**
 * Defines the settings for sorting the TreeList.
 */
export type SortSettings = boolean | ColumnSortSettings & {
    /**
     * Sets the sort mode of the TreeList.
     *
     */
    mode?: 'single' | 'multiple';
    /**
     * Enables the sort-sequence indicators for sorting multiple columns.
     */
    showIndexes?: boolean;
};
/**
 * @hidden
 */
export declare const normalize: (...settings: (SortSettings | ColumnSortSettings)[]) => any;
