/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TreeListComponent } from "../treelist.component";
/**
 * Provides the arguments for the `cellClick` event.
 * Use this interface to access information about the clicked cell, including its column, row, data item, and event type.
 */
export interface CellClickEvent {
    /**
     * The column of the clicked cell.
     */
    column: any;
    /**
     * The column index of the clicked cell.
     */
    columnIndex: number;
    /**
     * The data item associated with the row containing the clicked cell.
     */
    dataItem: any;
    /**
     * Specifies if the cell is being edited.
     */
    isEdited: boolean;
    /**
     * The DOM event that triggered the `cellClick` event.
     */
    originalEvent: any;
    /**
     * The row index for the operation.
     */
    rowIndex: number;
    /**
     * @hidden
     * @deprecated
     *
     * A deprecated alias for `rowIndex`.
     */
    index: number;
    /**
     * The `TreeListComponent` instance.
     */
    sender: TreeListComponent;
    /**
     * The type of the event that triggered the `cellClick` event.
     */
    type: 'click' | 'contextmenu';
}
