/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the type of the TreeList pager. Use this type to specify the pager style.
 *
 * The available values are:
 * * `numeric`&mdash;Buttons with numbers.
 * * `input`&mdash;Input for typing the page number.
 *
 * @example
 * ```html
 * <kendo-treelist [pageable]="{ type: 'numeric' }"></kendo-treelist>
 * ```
 */
export type PagerType = 'numeric' | 'input';
/**
 * Represents the pager settings of the TreeList. Use this interface to configure the pager options.
 *
 * @example
 * ```html
 * <kendo-treelist
 *    [pageable]="{
 *        buttonCount: 2,
 *        info: false
 *    }">
 * </kendo-treelist>
 * ```
 */
export interface PagerSettings {
    /**
     * Sets the maximum numeric buttons count before the buttons collapse.
     */
    buttonCount?: number;
    /**
     * Indicates if child nodes are fetched and counted for the pager total.
     */
    countChildren?: boolean;
    /**
     * Shows information about the current page and the total number of records.
     */
    info?: boolean;
    /**
     * Defines the type of the TreeList pager.
     */
    type?: PagerType;
    /**
     * Shows a menu for selecting the page size.
     */
    pageSizes?: boolean | Array<number>;
    /**
     * Toggles the **Previous** and **Next** buttons.
     */
    previousNext?: boolean;
    /**
     * Toggles the built-in responsive behavior of the Pager.
     * Available in version `3.0.0` and above ([see example](slug:responsive_pager_treelist)).
     */
    responsive?: boolean;
}
/**
 * @hidden
 */
export declare const normalize: (settings: any) => any;
