/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PopupService, PopupRef } from '@progress/kendo-angular-popup';
import { Renderer2, NgZone, OnDestroy } from '@angular/core';
import { PreventableEvent } from './preventable-event';
import { Subject } from 'rxjs';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ScrollSyncService } from '../scrolling/scroll-sync.service';
import * as i0 from "@angular/core";
/**
 * Provides arguments for the `close` event of the filter and column-menu popup. Use this event to access the original DOM event that triggers the popup to close and to prevent the default closing behavior if needed.
 */
export declare class PopupCloseEvent extends PreventableEvent {
    /**
     * Stores the original DOM event that causes the popup to close.
     */
    originalEvent: any;
    /**
     * @hidden
     */
    constructor(e: any);
}
/**
 * Represents the service used for the popups of the filter and column menus.
 * Use this service to manage popup opening, closing, and event handling.
 * ([See example]({% slug filter_menu_treelist %}#toc-filter-menu-with-popup)).
 */
export declare class SinglePopupService implements OnDestroy {
    private popupService;
    private renderer;
    private ngZone;
    private localization;
    /**
     * Emits when the filter or column menus are about to close because the user clicked outside their popups.
     * Use this event to prevent the popup from closing.
     */
    readonly onClose: Subject<PopupCloseEvent>;
    private removeClick;
    private popupRef;
    private scrollSubscription;
    /**
     * @hidden
     */
    constructor(popupService: PopupService, renderer: Renderer2, ngZone: NgZone, scrollSyncService: ScrollSyncService, localization: LocalizationService);
    /**
     * @hidden
     */
    open(anchor: any, template: any, popupRef: PopupRef, popupClass?: string): PopupRef;
    /**
     * @hidden
     */
    destroy(): void;
    ngOnDestroy(): void;
    private detachClose;
    private attachClose;
    static ɵfac: i0.ɵɵFactoryDeclaration<SinglePopupService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SinglePopupService>;
}
