/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from '../common/preventable-event';
import { ColumnBase } from '../columns/column-base';
/**
 * Provides arguments for the `columnReorder` event. Use this event to access the reordered column and its new and old indexes.
 */
export declare class ColumnReorderEvent extends PreventableEvent {
    /**
     * Specifies the reordered column.
     */
    readonly column: ColumnBase;
    /**
     * The new index of the column, relative to the collection of columns.
     */
    readonly newIndex: number;
    /**
     * The original index of the column before reordering, relative to the collection of columns.
     */
    readonly oldIndex: number;
    /**
     * @hidden
     */
    constructor({ column, newIndex, oldIndex }: any);
}
