/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The interface for the `editService` that you can set to the
 * [editing directives]({% slug editing_directives_treelist %}#toc-custom-service) of the TreeList.
 */
export interface EditService {
    /**
     * Creates a new item.
     * @param item The item to create.
     * @param parent The parent item, if any.
     * @param id The unique identifier, if any.
     */
    create(item: any, parent?: any, id?: any): void;
    /**
     * Updates the items for an existing item.
     * @param item The item to update.
     */
    update(item: any): void;
    /**
     * Removes an existing item.
     * @param item The item to remove.
     * @param parent The parent item, if any.
     */
    remove(item: any, parent?: any): void;
    /**
     * Sets new values to an item.
     * @param target The item to update.
     * @param source The values to assign.
     */
    assignValues(target: any, source: any): void;
}
