/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EditingDirectiveBase } from './editing-directive-base';
import { TreeListComponent } from '../treelist.component';
import { CreateFormGroup } from '../common/create-form-group';
import * as i0 from "@angular/core";
/**
 * A directive that encapsulates the editing operations of the TreeList when using the in-cell
 * editing with Reactive Forms. [See example](slug:editing_directives_treelist#toc-in-cell-editing-directive).
 *
 * @example
 * ```html
 * <kendo-treelist [kendoTreeListInCellEditing]="createFormGroup">
 *   <kendo-treelist-column field="name" title="Name"></kendo-treelist-column>
 *   <kendo-treelist-column field="age" title="Age"></kendo-treelist-column>
 * </kendo-treelist>
 * ```
 * @remarks
 * Applied to: {@link TreeListComponent}.
 */
export declare class InCellEditingDirective extends EditingDirectiveBase {
    protected treelist: TreeListComponent;
    /**
     * The function that creates the `FormGroup` for the edited model.
     */
    createFormGroup: CreateFormGroup;
    constructor(treelist: TreeListComponent);
    protected createModel(args: any): any;
    protected saveModel({ dataItem, formGroup, isNew }: any): any;
    /**
     * @hidden
     */
    ngOnInit(): void;
    protected removeHandler(args: any): void;
    protected cellClickHandler(args: any): void;
    protected cellCloseHandler(args: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InCellEditingDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<InCellEditingDirective, "[kendoTreeListInCellEditing]", ["kendoTreeListInCellEditing"], { "createFormGroup": { "alias": "kendoTreeListInCellEditing"; "required": false; }; }, {}, never, never, true, never>;
}
