/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { RowEditingDirectiveBase } from './row-editing-directive-base';
import { TreeListComponent } from '../treelist.component';
import { CreateFormGroup } from '../common/create-form-group';
import * as i0 from "@angular/core";
/**
 * A directive that encapsulates the editing operations of the TreeList when using the
 * Reactive Forms. [See example](slug:editing_directives_treelist#toc-reactive-editing-directive).
 *
 * @example
 * ```html
 * <kendo-treelist [kendoTreeListReactiveEditing]="createFormGroup">
 *   <kendo-treelist-column field="name" title="Name"></kendo-treelist-column>
 *   <kendo-treelist-column field="age" title="Age"></kendo-treelist-column>
 * </kendo-treelist>
 * ```
 * @remarks
 * Applied to: {@link TreeListComponent}.
 */
export declare class ReactiveEditingDirective extends RowEditingDirectiveBase {
    protected treelist: TreeListComponent;
    /**
     * The function that creates the `FormGroup` for the edited model.
     */
    createFormGroup: CreateFormGroup;
    constructor(treelist: TreeListComponent);
    protected createModel(args: any): any;
    protected saveModel({ dataItem, formGroup, isNew }: any): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<ReactiveEditingDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ReactiveEditingDirective, "[kendoTreeListReactiveEditing]", ["kendoTreeListReactiveEditing"], { "createFormGroup": { "alias": "kendoTreeListReactiveEditing"; "required": false; }; }, {}, never, never, true, never>;
}
