/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { RowEditingDirectiveBase } from './row-editing-directive-base';
import { TreeListComponent } from '../treelist.component';
import * as i0 from "@angular/core";
/**
 * A directive that encapsulates the editing operations of the TreeList when using
 * Template-Driven Angular Forms. [See example](slug:editing_directives_treelist#toc-template-editing-directive).
 *
 * @example
 * ```html
 * <kendo-treelist [kendoTreeListTemplateEditing]="createNewItem">
 *   <kendo-treelist-column field="name" title="Name"></kendo-treelist-column>
 *   <kendo-treelist-column field="age" title="Age"></kendo-treelist-column>
 * </kendo-treelist>
 * ```
 * @remarks
 * Applied to: {@link TreeListComponent}.
 */
export declare class TemplateEditingDirective extends RowEditingDirectiveBase {
    protected treelist: TreeListComponent;
    /**
     * The function that creates the `dataItem` for new rows.
     */
    createNewItem: Function;
    protected originalValues: any;
    constructor(treelist: TreeListComponent);
    protected editHandler(args: any): void;
    protected closeEditor(args?: any): void;
    protected createModel(args: any): any;
    protected saveModel(args: any): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<TemplateEditingDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TemplateEditingDirective, "[kendoTreeListTemplateEditing]", ["kendoTreeListTemplateEditing"], { "createNewItem": { "alias": "kendoTreeListTemplateEditing"; "required": false; }; }, {}, never, never, true, never>;
}
