/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EditService } from './edit.service';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import * as i0 from "@angular/core";
/**
 * Represents the command for adding a new item to the TreeList. Apply this directive to any `kendo-toolbar-button` element inside a ToolbarComponent. When the user clicks the toolbar button associated with the directive, the [`add`]({% slug api_treelist_treelistcomponent %}#toc-add) event is triggered.
 *
 * @example
 * ```html
 * <kendo-treelist>
 *   <kendo-toolbar>
 *     <kendo-toolbar-button text="Add new" kendoTreeListAddTool></kendo-toolbar-button>
 *   </kendo-toolbar>
 * </kendo-treelist>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}
 */
export declare class AddCommandToolbarDirective {
    private editService;
    private host;
    private clickSub;
    constructor(editService: EditService, host: ToolBarButtonComponent);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AddCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AddCommandToolbarDirective, "[kendoTreeListAddTool]", never, {}, {}, never, never, true, never>;
}
