/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2, NgZone } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { EditService } from './edit.service';
import { BaseCommandDirective } from './base-command.directive';
import * as i0 from "@angular/core";
/**
 * Represents the `edit` command of the TreeList. Apply this directive to any `button` element inside a [`CommandColumnComponent`]({% slug api_treelist_commandcolumncomponent %}).
 *
 * When the user clicks a button with this directive, the [`edit`]({% slug api_treelist_treelistcomponent %}#toc-edit) event is triggered ([see example](slug:custom_editors_editing_treelist)).
 *
 * The button with `kendoTreeListEditCommand` is automatically hidden when the row is in edit mode. The directive takes the `cellContext` from the cell template as input.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-command-column title="command">
 *     <ng-template kendoTreeListCellTemplate let-cellContext="cellContext">
 *       <button [kendoTreeListEditCommand]="cellContext">Edit</button>
 *     </ng-template>
 *   </kendo-treelist-command-column>
 * </kendo-treelist>
 * ```
 */
export declare class EditCommandDirective extends BaseCommandDirective {
    /**
     * Provides the `cellContext` to the template.
     */
    cellContext: any;
    commandClass: boolean;
    protected readVisible: boolean;
    constructor(editService: EditService, element: ElementRef, renderer: Renderer2, localization: LocalizationService, ngZone: NgZone);
    protected onClick(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditCommandDirective, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EditCommandDirective, "[kendoTreeListEditCommand]", never, { "cellContext": { "alias": "kendoTreeListEditCommand"; "required": false; }; }, {}, never, ["*"], true, never>;
}
