/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, forwardRef, ContentChild, SkipSelf, Host, Optional, Input } from '@angular/core';
import { ColumnBase } from './column-base';
import { CellTemplateDirective } from '../rendering/cell-template.directive';
import * as i0 from "@angular/core";
import * as i1 from "./column-base";
/**
 * Represents the checkbox column for selecting rows in the TreeList. [See example](slug:treelist_row_selection#toc-select-all-checkbox).
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-checkbox-column
 *     [showSelectAll]="true"
 *     [checkChildren]="true"
 *     [expandable]="true">
 *   </kendo-treelist-checkbox-column>
 *   <kendo-treelist-column field="ProductName" title="Product Name"></kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export class CheckboxColumnComponent extends ColumnBase {
    parent;
    /**
     * Specifies if a select-all checkbox appears in the header.
     */
    showSelectAll;
    /**
     * Specifies if clicking the checkbox selects or deselects all children.
     */
    checkChildren;
    /**
     * Specifies if the expanded indicator appears in the column.
     * @default false
     */
    expandable;
    /*
     * @hidden
     */
    isCheckboxColumn = true;
    template;
    constructor(parent) {
        super(parent);
        this.parent = parent;
    }
    get templateRef() {
        return this.template ? this.template.templateRef : undefined;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CheckboxColumnComponent, deps: [{ token: i1.ColumnBase, host: true, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CheckboxColumnComponent, isStandalone: true, selector: "kendo-treelist-checkbox-column", inputs: { showSelectAll: "showSelectAll", checkChildren: "checkChildren", expandable: "expandable" }, providers: [
            {
                provide: ColumnBase,
                useExisting: forwardRef(() => CheckboxColumnComponent)
            }
        ], queries: [{ propertyName: "template", first: true, predicate: CellTemplateDirective, descendants: true }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CheckboxColumnComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [
                        {
                            provide: ColumnBase,
                            useExisting: forwardRef(() => CheckboxColumnComponent)
                        }
                    ],
                    selector: 'kendo-treelist-checkbox-column',
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.ColumnBase, decorators: [{
                    type: SkipSelf
                }, {
                    type: Host
                }, {
                    type: Optional
                }] }]; }, propDecorators: { showSelectAll: [{
                type: Input
            }], checkChildren: [{
                type: Input
            }], expandable: [{
                type: Input
            }], template: [{
                type: ContentChild,
                args: [CellTemplateDirective, { static: false }]
            }] } });
