/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from '../common/preventable-event';
/**
 * Provides arguments for the `columnReorder` event. Use this event to access the reordered column and its new and old indexes.
 */
export class ColumnReorderEvent extends PreventableEvent {
    /**
     * Specifies the reordered column.
     */
    column;
    /**
     * The new index of the column, relative to the collection of columns.
     */
    newIndex;
    /**
     * The original index of the column before reordering, relative to the collection of columns.
     */
    oldIndex;
    /**
     * @hidden
     */
    constructor({ column, newIndex, oldIndex }) {
        super();
        this.column = column;
        this.newIndex = newIndex;
        this.oldIndex = oldIndex;
    }
}
