/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, TemplateRef, Optional } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the filter-cell template for the TreeList.
 * Use this directive to customize the filter row cell for a column.
 * See [custom filter row components](slug:filter_row_treelist#toc-custom-filters).
 *
 * The template context is set to the filter descriptor and provides the following fields:
 * - `column`&mdash;The current column instance. Use as an alias for a template variable with `let-column="column"`.
 * - `filter`&mdash;The filter descriptor.
 * - `cellContext`&mdash;An object used to pass context information to built-in directives.
 *
 * @example
 * ```html
 * <kendo-treelist-column field="name" title="Name">
 *   <ng-template kendoTreeListFilterCellTemplate let-column="column" let-filter="filter" let-cellContext="cellContext">
 *     <kendo-maskedtextbox mask="(999) 000-0000"
 *        [promptPlaceholder]="prompt" [includeLiterals]="true"
 *        (valueChange)="phoneChange($event)"
 *      >
 *      </kendo-maskedtextbox>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export class FilterCellTemplateDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterCellTemplateDirective, deps: [{ token: i0.TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: FilterCellTemplateDirective, isStandalone: true, selector: "[kendoTreeListFilterCellTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterCellTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoTreeListFilterCellTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef, decorators: [{
                    type: Optional
                }] }]; } });
