/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, TemplateRef, Optional } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the filter-menu template for the TreeList filter menu.
 *
 * Use this directive to provide a custom template for the filter menu in a TreeList column
 * ([see example](slug:filter_menu_treelist#toc-custom-filter-menu-components)).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="title" title="Title" [width]="180">
 *  <ng-template kendoTreeListFilterMenuTemplate
 *    let-filter="filter"
 *    let-filterService="filterService">
 *      <my-custom-filter-menu-component
 *          [currentFilter]="filter"
 *          [filterService]="filterService">
 *      </my-custom-filter-menu-component>
 *  </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export class FilterMenuTemplateDirective {
    templateRef;
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterMenuTemplateDirective, deps: [{ token: i0.TemplateRef, optional: true }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: FilterMenuTemplateDirective, isStandalone: true, selector: "[kendoTreeListFilterMenuTemplate]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterMenuTemplateDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoTreeListFilterMenuTemplate]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.TemplateRef, decorators: [{
                    type: Optional
                }] }]; } });
