/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, forwardRef } from '@angular/core';
import { FilterOperatorBase } from './filter-operator.base';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
/**
 * Represents the `Less than` (**Is before**) [date filter operator](slug:filtering_treelist#toc-date-filter) for the TreeList.
 * Use this operator to filter dates that are before a specific value.
 * [See example](slug:filter_row_treelist#toc-setting-the-default-filter-operator).
 *
 * @example
 * ```html Filer Cell
 * <kendo-treelist-column field="hireDate">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-date-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-treelist-filter-before-operator></kendo-treelist-filter-before-operator>
 *      </kendo-treelist-date-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * ```html Filter Menu
 * <kendo-treelist-column field="hireDate">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-date-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-treelist-filter-before-operator></kendo-treelist-filter-before-operator>
 *     </kendo-treelist-date-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export class BeforeFilterOperatorComponent extends FilterOperatorBase {
    constructor(localization) { super('before', localization); }
    /**
     * @hidden
     */
    toJSON() {
        return {
            text: this.text,
            value: 'lt'
        };
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BeforeFilterOperatorComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: BeforeFilterOperatorComponent, isStandalone: true, selector: "kendo-treelist-filter-before-operator", providers: [
            {
                provide: FilterOperatorBase,
                useExisting: forwardRef(() => BeforeFilterOperatorComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BeforeFilterOperatorComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [
                        {
                            provide: FilterOperatorBase,
                            useExisting: forwardRef(() => BeforeFilterOperatorComponent)
                        }
                    ],
                    selector: 'kendo-treelist-filter-before-operator',
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });
