/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Inject, Input } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { isNullOrEmptyString } from '../../utils';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
const localizeOperators = operators => localization => Object.keys(operators).reduce((acc, key) => {
    acc[operators[key]] = localization.get(key);
    return acc;
}, {});
const operatorTexts = localizeOperators({
    'filterEqOperator': 'eq',
    'filterNotEqOperator': 'neq',
    'filterGteOperator': 'gte',
    'filterGtOperator': 'gt',
    'filterLteOperator': 'lte',
    'filterLtOperator': 'lt',
    'filterIsNullOperator': 'isnull',
    'filterIsNotNullOperator': 'isnotnull',
    'filterIsEmptyOperator': 'isempty',
    'filterIsNotEmptyOperator': 'isnotempty',
    'filterContainsOperator': 'contains',
    'filterNotContainsOperator': 'doesnotcontain',
    'filterStartsWithOperator': 'startswith',
    'filterEndsWithOperator': 'endswith',
    'filterAfterOrEqualOperator': 'after-eq',
    'filterAfterOperator': 'after',
    'filterBeforeOrEqualOperator': 'before-eq',
    'filterBeforeOperator': 'before'
});
/**
 * @hidden
 */
export const toJSON = (xs) => xs.map(x => x.toJSON());
/**
 * @hidden
 */
export class FilterOperatorBase {
    operator;
    localization;
    /**
     * The text displayed in the drop-down list for the filter operator.
     * @readonly
     * @type {string}
     * @memberOf FilterOperatorBase
     */
    get text() {
        return this._text;
    }
    set text(value) {
        this._text = isNullOrEmptyString(value) ? this.messages[this.operator] : value;
    }
    subscription;
    messages;
    _text;
    constructor(operator, localization) {
        this.operator = operator;
        this.localization = localization;
        this.messages = operatorTexts(this.localization);
        this._text = this.messages[this.operator];
        this.subscription = this.localization.changes.subscribe(this.refreshText.bind(this));
    }
    ngOnDestroy() {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    }
    /**
     * @hidden
     */
    toJSON() {
        return {
            text: this.text,
            value: this.operator
        };
    }
    refreshText() {
        const update = this._text === this.messages[this.operator];
        this.messages = operatorTexts(this.localization);
        if (update) {
            this._text = this.messages[this.operator];
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterOperatorBase, deps: [{ token: 'filterOperator' }, { token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: FilterOperatorBase, inputs: { text: "text" }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterOperatorBase, decorators: [{
            type: Directive,
            args: [{}]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: ['filterOperator']
                }] }, { type: i1.LocalizationService }]; }, propDecorators: { text: [{
                type: Input
            }] } });
