/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { IconsService } from '@progress/kendo-angular-icons';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, NavigationService, YearViewService } from '@progress/kendo-angular-dateinputs';
import { PopupService } from '@progress/kendo-angular-popup';
import { DialogContainerService, DialogService, WindowContainerService, WindowService } from '@progress/kendo-angular-dialog';
import { KENDO_TREELIST } from './directives';
import { TableDirective } from './column-resizing/table.directive';
import { KENDO_TOOLBAR } from '@progress/kendo-angular-toolbar';
import { KENDO_PAGER } from '@progress/kendo-angular-pager';
import * as i0 from "@angular/core";
import * as i1 from "./treelist.component";
import * as i2 from "./rendering/toolbar/toolbar-template.directive";
import * as i3 from "./rendering/toolbar/toolbar.component";
import * as i4 from "./rendering/common/spacer.component";
import * as i5 from "./localization/custom-messages.component";
import * as i6 from "./editing-directives/template-editing.directive";
import * as i7 from "./editing-directives/reactive-editing.directive";
import * as i8 from "./editing-directives/in-cell-editing.directive";
import * as i9 from "./binding-directives/hierarchy-binding.directive";
import * as i10 from "./binding-directives/flat-binding.directive";
import * as i11 from "./expand-state/expandable.directive";
import * as i12 from "./selection/selectable.directive";
import * as i13 from "./rendering/toolbar/toolbar-focusable.directive";
import * as i14 from "./columns/column.component";
import * as i15 from "./columns/column-group.component";
import * as i16 from "./navigation/logical-cell.directive";
import * as i17 from "./navigation/logical-row.directive";
import * as i18 from "./navigation/focusable.directive";
import * as i19 from "./rendering/common/col-group.component";
import * as i20 from "./layout/resizable.directive";
import * as i21 from "@progress/kendo-angular-common";
import * as i22 from "./rendering/common/field-accessor.pipe";
import * as i23 from "./columns/span-column.component";
import * as i24 from "./rendering/common/loading.component";
import * as i25 from "./filtering/cell/filter-cell-operators.component";
import * as i26 from "./columns/checkbox-column.component";
import * as i27 from "./columns/rowreorder-column.component";
import * as i28 from "./columns/command-column.component";
import * as i29 from "./rendering/cell-template.directive";
import * as i30 from "./rendering/cell.component";
import * as i31 from "./rendering/no-records-template.directive";
import * as i32 from "./editing/edit-template.directive";
import * as i33 from "./editing/edit-command.directive";
import * as i34 from "./editing/cancel-command.directive";
import * as i35 from "./editing/save-command.directive";
import * as i36 from "./editing/remove-command.directive";
import * as i37 from "./editing/add-command.directive";
import * as i38 from "./editing/add-command-tool.directive";
import * as i39 from "./rendering/footer-template.directive";
import * as i40 from "./rendering/header/header.component";
import * as i41 from "./rendering/header/header-template.directive";
import * as i42 from "./column-resizing/column-handle.directive";
import * as i43 from "./filtering/filter-row.component";
import * as i44 from "./filtering/cell/filter-cell.component";
import * as i45 from "./filtering/cell/filter-cell-template.directive";
import * as i46 from "./filtering/cell/string-filter-cell.component";
import * as i47 from "./filtering/cell/numeric-filter-cell.component";
import * as i48 from "./filtering/cell/autocomplete-filter-cell.component";
import * as i49 from "./filtering/cell/boolean-filter-cell.component";
import * as i50 from "./filtering/cell/filter-cell-host.directive";
import * as i51 from "./filtering/cell/filter-cell-wrapper.component";
import * as i52 from "./filtering/cell/date-filter-cell.component";
import * as i53 from "./filtering/operators/contains-filter-operator.component";
import * as i54 from "./filtering/operators/not-contains-filter-operator.component";
import * as i55 from "./filtering/operators/ends-with-filter-operator.component";
import * as i56 from "./filtering/operators/eq-filter-operator.component";
import * as i57 from "./filtering/operators/is-empty-filter-operator.component";
import * as i58 from "./filtering/operators/is-not-empty-filter-operator.component";
import * as i59 from "./filtering/operators/is-not-null-filter-operator.component";
import * as i60 from "./filtering/operators/isnull-filter-operator.component";
import * as i61 from "./filtering/operators/neq-filter-operator.component";
import * as i62 from "./filtering/operators/starts-with-filter-operator.component";
import * as i63 from "./filtering/operators/gt-filter-operator.component";
import * as i64 from "./filtering/operators/gte-filter-operator.component";
import * as i65 from "./filtering/operators/lt-filter-operator.component";
import * as i66 from "./filtering/operators/lte-filter-operator.component";
import * as i67 from "./filtering/operators/after-filter-operator.component";
import * as i68 from "./filtering/operators/after-eq-filter-operator.component";
import * as i69 from "./filtering/operators/before-eq-filter-operator.component";
import * as i70 from "./filtering/operators/before-filter-operator.component";
import * as i71 from "./filtering/filter-input.directive";
import * as i72 from "./filtering/menu/filter-menu.component";
import * as i73 from "./filtering/menu/filter-menu-container.component";
import * as i74 from "./filtering/menu/filter-menu-input-wrapper.component";
import * as i75 from "./filtering/menu/string-filter-menu-input.component";
import * as i76 from "./filtering/menu/string-filter-menu.component";
import * as i77 from "./filtering/menu/filter-menu-template.directive";
import * as i78 from "./filtering/menu/numeric-filter-menu.component";
import * as i79 from "./filtering/menu/numeric-filter-menu-input.component";
import * as i80 from "./filtering/menu/date-filter-menu-input.component";
import * as i81 from "./filtering/menu/date-filter-menu.component";
import * as i82 from "./filtering/menu/filter-menu-host.directive";
import * as i83 from "./filtering/menu/boolean-filter-menu.component";
import * as i84 from "./filtering/menu/filter-radio-button.directive";
import * as i85 from "./column-menu/column-chooser.component";
import * as i86 from "./column-menu/column-menu-chooser.component";
import * as i87 from "./column-menu/column-menu-filter.component";
import * as i88 from "./column-menu/column-menu-item.component";
import * as i89 from "./column-menu/column-menu-item-content-template.directive";
import * as i90 from "./column-menu/column-menu-sort.component";
import * as i91 from "./column-menu/column-menu.component";
import * as i92 from "./column-menu/column-menu-lock.component";
import * as i93 from "./column-menu/column-menu-template.directive";
import * as i94 from "./column-menu/column-menu-item.directive";
import * as i95 from "./excel/excel.component";
import * as i96 from "./excel/excel-command.directive";
import * as i97 from "./excel/excel-command-tool.directive";
import * as i98 from "@progress/kendo-angular-excel-export";
import * as i99 from "./pdf/pdf.component";
import * as i100 from "./pdf/pdf-margin.component";
import * as i101 from "./pdf/pdf-command.directive";
import * as i102 from "./pdf/pdf-template.directive";
import * as i103 from "./pdf/pdf-command-tool.directive";
import * as i104 from "@progress/kendo-angular-toolbar";
import * as i105 from "@progress/kendo-angular-pager";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [`NgModule`](link:site.data.urls.angular['ngmoduleapi']) definition for the TreeList component.
 * Use this module to enable TreeList features in your application.
 *
 * @example
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { TreeListModule } from '@progress/kendo-angular-treelist';
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *   declarations: [AppComponent],
 *   imports: [BrowserModule, TreeListModule],
 *   bootstrap: [AppComponent]
 * })
 * export class AppModule {}
 * ```
 */
export class TreeListModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreeListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: TreeListModule, imports: [i1.TreeListComponent, i2.ToolbarTemplateDirective, i3.ToolbarComponent, i4.TreeListSpacerComponent, i5.CustomMessagesComponent, i6.TemplateEditingDirective, i7.ReactiveEditingDirective, i8.InCellEditingDirective, i9.HierarchyBindingDirective, i10.FlatBindingDirective, i11.ExpandableDirective, i12.SelectableDirective, i13.TreeListToolbarFocusableDirective, i14.ColumnComponent, i15.ColumnGroupComponent, i16.LogicalCellDirective, i17.LogicalRowDirective, i18.FocusableDirective, i19.ColGroupComponent, i20.ResizableContainerDirective, i21.TemplateContextDirective, i22.FieldAccessorPipe, i23.SpanColumnComponent, i24.LoadingComponent, i25.FilterCellOperatorsComponent, i26.CheckboxColumnComponent, i27.RowReorderColumnComponent, i28.CommandColumnComponent, i29.CellTemplateDirective, i30.CellComponent, i31.NoRecordsTemplateDirective, i32.EditTemplateDirective, i33.EditCommandDirective, i34.CancelCommandDirective, i35.SaveCommandDirective, i36.RemoveCommandDirective, i37.AddCommandDirective, i38.AddCommandToolbarDirective, i39.FooterTemplateDirective, i40.HeaderComponent, i41.HeaderTemplateDirective, i42.ColumnHandleDirective, i43.FilterRowComponent, i44.FilterCellComponent, i45.FilterCellTemplateDirective, i46.StringFilterCellComponent, i47.NumericFilterCellComponent, i48.AutoCompleteFilterCellComponent, i49.BooleanFilterCellComponent, i50.FilterCellHostDirective, i51.FilterCellWrapperComponent, i52.DateFilterCellComponent, i25.FilterCellOperatorsComponent, i53.ContainsFilterOperatorComponent, i54.DoesNotContainFilterOperatorComponent, i55.EndsWithFilterOperatorComponent, i56.EqualFilterOperatorComponent, i57.IsEmptyFilterOperatorComponent, i58.IsNotEmptyFilterOperatorComponent, i59.IsNotNullFilterOperatorComponent, i60.IsNullFilterOperatorComponent, i61.NotEqualFilterOperatorComponent, i62.StartsWithFilterOperatorComponent, i63.GreaterFilterOperatorComponent, i64.GreaterOrEqualToFilterOperatorComponent, i65.LessFilterOperatorComponent, i66.LessOrEqualToFilterOperatorComponent, i67.AfterFilterOperatorComponent, i68.AfterEqFilterOperatorComponent, i69.BeforeEqFilterOperatorComponent, i70.BeforeFilterOperatorComponent, i71.FilterInputDirective, i14.ColumnComponent, i15.ColumnGroupComponent, i16.LogicalCellDirective, i17.LogicalRowDirective, i18.FocusableDirective, i19.ColGroupComponent, i20.ResizableContainerDirective, i21.TemplateContextDirective, i22.FieldAccessorPipe, i23.SpanColumnComponent, i24.LoadingComponent, i25.FilterCellOperatorsComponent, i26.CheckboxColumnComponent, i27.RowReorderColumnComponent, i72.FilterMenuComponent, i73.FilterMenuContainerComponent, i74.FilterMenuInputWrapperComponent, i75.StringFilterMenuInputComponent, i76.StringFilterMenuComponent, i77.FilterMenuTemplateDirective, i78.NumericFilterMenuComponent, i79.NumericFilterMenuInputComponent, i80.DateFilterMenuInputComponent, i81.DateFilterMenuComponent, i82.FilterMenuHostDirective, i83.BooleanFilterMenuComponent, i84.BooleanFilterRadioButtonDirective, i85.ColumnChooserComponent, i86.ColumnMenuChooserComponent, i87.ColumnMenuFilterComponent, i88.ColumnMenuItemComponent, i89.ColumnMenuItemContentTemplateDirective, i90.ColumnMenuSortComponent, i91.ColumnMenuComponent, i92.ColumnMenuLockComponent, i93.ColumnMenuTemplateDirective, i94.ColumnMenuItemDirective, i95.ExcelComponent, i96.ExcelCommandDirective, i97.ExcelCommandToolbarDirective, i98.ColumnComponent, i98.ColumnGroupComponent, i98.FooterTemplateDirective, i98.GroupFooterTemplateDirective, i98.GroupHeaderColumnTemplateDirective, i98.GroupHeaderTemplateDirective, i99.PDFComponent, i100.PDFMarginComponent, i101.PDFCommandDirective, i102.PDFTemplateDirective, i103.PDFCommandToolbarDirective, i104.ToolBarComponent, i104.ToolbarCustomMessagesComponent, i104.ToolBarButtonComponent, i104.ToolBarButtonGroupComponent, i104.ToolBarDropDownButtonComponent, i104.ToolBarSeparatorComponent, i104.ToolBarSpacerComponent, i104.ToolBarSplitButtonComponent, i104.ToolBarToolComponent, i105.CustomMessagesComponent, i105.PagerFocusableDirective, i105.PagerInfoComponent, i105.PagerInputComponent, i105.PagerNextButtonsComponent, i105.PagerNumericButtonsComponent, i105.PagerPageSizesComponent, i105.PagerPrevButtonsComponent, i105.PagerTemplateDirective, i105.PagerComponent, i105.PagerSpacerComponent, TableDirective], exports: [i1.TreeListComponent, i2.ToolbarTemplateDirective, i3.ToolbarComponent, i4.TreeListSpacerComponent, i5.CustomMessagesComponent, i6.TemplateEditingDirective, i7.ReactiveEditingDirective, i8.InCellEditingDirective, i9.HierarchyBindingDirective, i10.FlatBindingDirective, i11.ExpandableDirective, i12.SelectableDirective, i13.TreeListToolbarFocusableDirective, i14.ColumnComponent, i15.ColumnGroupComponent, i16.LogicalCellDirective, i17.LogicalRowDirective, i18.FocusableDirective, i19.ColGroupComponent, i20.ResizableContainerDirective, i21.TemplateContextDirective, i22.FieldAccessorPipe, i23.SpanColumnComponent, i24.LoadingComponent, i25.FilterCellOperatorsComponent, i26.CheckboxColumnComponent, i27.RowReorderColumnComponent, i28.CommandColumnComponent, i29.CellTemplateDirective, i30.CellComponent, i31.NoRecordsTemplateDirective, i32.EditTemplateDirective, i33.EditCommandDirective, i34.CancelCommandDirective, i35.SaveCommandDirective, i36.RemoveCommandDirective, i37.AddCommandDirective, i38.AddCommandToolbarDirective, i39.FooterTemplateDirective, i40.HeaderComponent, i41.HeaderTemplateDirective, i42.ColumnHandleDirective, i43.FilterRowComponent, i44.FilterCellComponent, i45.FilterCellTemplateDirective, i46.StringFilterCellComponent, i47.NumericFilterCellComponent, i48.AutoCompleteFilterCellComponent, i49.BooleanFilterCellComponent, i50.FilterCellHostDirective, i51.FilterCellWrapperComponent, i52.DateFilterCellComponent, i25.FilterCellOperatorsComponent, i53.ContainsFilterOperatorComponent, i54.DoesNotContainFilterOperatorComponent, i55.EndsWithFilterOperatorComponent, i56.EqualFilterOperatorComponent, i57.IsEmptyFilterOperatorComponent, i58.IsNotEmptyFilterOperatorComponent, i59.IsNotNullFilterOperatorComponent, i60.IsNullFilterOperatorComponent, i61.NotEqualFilterOperatorComponent, i62.StartsWithFilterOperatorComponent, i63.GreaterFilterOperatorComponent, i64.GreaterOrEqualToFilterOperatorComponent, i65.LessFilterOperatorComponent, i66.LessOrEqualToFilterOperatorComponent, i67.AfterFilterOperatorComponent, i68.AfterEqFilterOperatorComponent, i69.BeforeEqFilterOperatorComponent, i70.BeforeFilterOperatorComponent, i71.FilterInputDirective, i14.ColumnComponent, i15.ColumnGroupComponent, i16.LogicalCellDirective, i17.LogicalRowDirective, i18.FocusableDirective, i19.ColGroupComponent, i20.ResizableContainerDirective, i21.TemplateContextDirective, i22.FieldAccessorPipe, i23.SpanColumnComponent, i24.LoadingComponent, i25.FilterCellOperatorsComponent, i26.CheckboxColumnComponent, i27.RowReorderColumnComponent, i72.FilterMenuComponent, i73.FilterMenuContainerComponent, i74.FilterMenuInputWrapperComponent, i75.StringFilterMenuInputComponent, i76.StringFilterMenuComponent, i77.FilterMenuTemplateDirective, i78.NumericFilterMenuComponent, i79.NumericFilterMenuInputComponent, i80.DateFilterMenuInputComponent, i81.DateFilterMenuComponent, i82.FilterMenuHostDirective, i83.BooleanFilterMenuComponent, i84.BooleanFilterRadioButtonDirective, i85.ColumnChooserComponent, i86.ColumnMenuChooserComponent, i87.ColumnMenuFilterComponent, i88.ColumnMenuItemComponent, i89.ColumnMenuItemContentTemplateDirective, i90.ColumnMenuSortComponent, i91.ColumnMenuComponent, i92.ColumnMenuLockComponent, i93.ColumnMenuTemplateDirective, i94.ColumnMenuItemDirective, i95.ExcelComponent, i96.ExcelCommandDirective, i97.ExcelCommandToolbarDirective, i98.ColumnComponent, i98.ColumnGroupComponent, i98.FooterTemplateDirective, i98.GroupFooterTemplateDirective, i98.GroupHeaderColumnTemplateDirective, i98.GroupHeaderTemplateDirective, i99.PDFComponent, i100.PDFMarginComponent, i101.PDFCommandDirective, i102.PDFTemplateDirective, i103.PDFCommandToolbarDirective, i104.ToolBarComponent, i104.ToolbarCustomMessagesComponent, i104.ToolBarButtonComponent, i104.ToolBarButtonGroupComponent, i104.ToolBarDropDownButtonComponent, i104.ToolBarSeparatorComponent, i104.ToolBarSpacerComponent, i104.ToolBarSplitButtonComponent, i104.ToolBarToolComponent, i105.CustomMessagesComponent, i105.PagerFocusableDirective, i105.PagerInfoComponent, i105.PagerInputComponent, i105.PagerNextButtonsComponent, i105.PagerNumericButtonsComponent, i105.PagerPageSizesComponent, i105.PagerPrevButtonsComponent, i105.PagerTemplateDirective, i105.PagerComponent, i105.PagerSpacerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreeListModule, providers: [
            IconsService,
            ResizeBatchService,
            CalendarDOMService,
            CenturyViewService,
            DecadeViewService,
            MonthViewService,
            YearViewService,
            PopupService,
            NavigationService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService
        ], imports: [i1.TreeListComponent, i25.FilterCellOperatorsComponent, i30.CellComponent, i33.EditCommandDirective, i34.CancelCommandDirective, i35.SaveCommandDirective, i36.RemoveCommandDirective, i37.AddCommandDirective, i40.HeaderComponent, i46.StringFilterCellComponent, i47.NumericFilterCellComponent, i48.AutoCompleteFilterCellComponent, i49.BooleanFilterCellComponent, i51.FilterCellWrapperComponent, i52.DateFilterCellComponent, i25.FilterCellOperatorsComponent, i25.FilterCellOperatorsComponent, i72.FilterMenuComponent, i73.FilterMenuContainerComponent, i74.FilterMenuInputWrapperComponent, i75.StringFilterMenuInputComponent, i76.StringFilterMenuComponent, i78.NumericFilterMenuComponent, i79.NumericFilterMenuInputComponent, i80.DateFilterMenuInputComponent, i81.DateFilterMenuComponent, i83.BooleanFilterMenuComponent, i85.ColumnChooserComponent, i86.ColumnMenuChooserComponent, i87.ColumnMenuFilterComponent, i88.ColumnMenuItemComponent, i90.ColumnMenuSortComponent, i91.ColumnMenuComponent, i92.ColumnMenuLockComponent, i96.ExcelCommandDirective, i98.ColumnComponent, i98.ColumnGroupComponent, i101.PDFCommandDirective, i104.ToolBarComponent, i104.ToolbarCustomMessagesComponent, i104.ToolBarButtonComponent, i104.ToolBarButtonGroupComponent, i104.ToolBarDropDownButtonComponent, i104.ToolBarSeparatorComponent, i104.ToolBarSpacerComponent, i104.ToolBarSplitButtonComponent, i105.CustomMessagesComponent, i105.PagerInfoComponent, i105.PagerInputComponent, i105.PagerNextButtonsComponent, i105.PagerNumericButtonsComponent, i105.PagerPageSizesComponent, i105.PagerPrevButtonsComponent, i105.PagerComponent, i105.PagerSpacerComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreeListModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_TREELIST, ...KENDO_TOOLBAR, ...KENDO_PAGER],
                    imports: [...KENDO_TREELIST, ...KENDO_TOOLBAR, ...KENDO_PAGER, TableDirective],
                    providers: [
                        IconsService,
                        ResizeBatchService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        PopupService,
                        NavigationService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService
                    ]
                }]
        }] });
