/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { ExcelService } from './excel.service';
import * as i0 from "@angular/core";
/**
 * Represents the `export-to-Excel` toolbar tool of the TreeList. Apply this directive to any `kendo-toolbar-button` element inside a ToolbarComponent used in the TreeList.
 *
 * When the user clicks a button with this directive, the [excelExport]({% slug api_treelist_treelistcomponent %}#toc-excelexport) event fires ([see example]({% slug excelexport_treelist %})).
 *
 * @example
 * ```html
 * <kendo-treelist>
 *     <kendo-toolbar>
 *         <kendo-toolbar-button text="Excel Export" kendoTreeListExcelTool></kendo-toolbar-button>
 *     </kendo-toolbar>
 *     <kendo-treelist-excel fileName="TreeList.xlsx">
 *     </kendo-treelist-excel>
 * </kendo-treelist>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}
 */
export declare class ExcelCommandToolbarDirective {
    private excelService;
    private host;
    private clickSub;
    constructor(excelService: ExcelService, host: ToolBarButtonComponent);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ExcelCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ExcelCommandToolbarDirective, "[kendoTreeListExcelTool]", never, {}, {}, never, never, true, never>;
}
