/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 as Renderer, NgZone } from '@angular/core';
import { Button } from '@progress/kendo-angular-buttons';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ExcelService } from './excel.service';
import * as i0 from "@angular/core";
/**
 * Represents the `export-to-Excel` command of the TreeList. Apply this directive to any `button` element inside a [`ToolbarTemplate`](slug:toolbartemplate_treelist).
 * When the user clicks a button with this directive, the [`excelExport`]({% slug api_treelist_treelistcomponent %}#toc-excelexport) event fires ([see example]({% slug excelexport_treelist %})).
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <ng-template kendoTreeListToolbarTemplate>
 *     <button kendoTreeListExcelCommand>Export to Excel</button>
 *   </ng-template>
 *   <kendo-treelist-excel fileName="TreeList.xlsx"> </kendo-treelist-excel>
 * </kendo-treelist>
 * ```
 */
export declare class ExcelCommandDirective extends Button {
    private excelService;
    /**
     * @hidden
     */
    onClick(e: any): void;
    /**
     * @hidden
     */
    get excelClass(): boolean;
    constructor(excelService: ExcelService, element: ElementRef, renderer: Renderer, localization: LocalizationService, ngZone: NgZone);
    static ɵfac: i0.ɵɵFactoryDeclaration<ExcelCommandDirective, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ExcelCommandDirective, "[kendoTreeListExcelCommand]", never, {}, {}, never, ["*"], true, never>;
}
