/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * @hidden
 *
 * An injection token used by the expand-directive to interface with the TreeList or the Gantt.
 */
export declare abstract class ExpandableTreeComponent {
    /**
     * Extracts the id value when `idField` is set.
     */
    abstract idGetter: any;
    /**
     * Emits when expand or collapse events occur.
     */
    abstract expandStateChange: EventEmitter<any>;
    /**
     * Sets the callback function that indicates if a particular TreeList item is expanded.
     */
    abstract isExpanded(node: any): boolean;
    /**
     * Updates the state of the current TreeList view without reloading data.
     * Checks all rendered items for changes and triggers re-evaluation of the `isExpanded` and `isSelected` callbacks.
     */
    abstract updateView(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ExpandableTreeComponent, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ExpandableTreeComponent>;
}
