/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { FilterService } from '../filter.service';
import { BooleanFilterComponent } from '../boolean-filter.component';
import * as i0 from "@angular/core";
/**
 * Represents a Boolean filter-cell component.
 * Use this component to filter Boolean values in the TreeList.
 * See the article about the [built-in filter components](slug:filter_row_treelist#toc-built-in-filter-row-components).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="ProductName" title="Product Name">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-boolean-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *     </kendo-treelist-boolean-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class BooleanFilterCellComponent extends BooleanFilterComponent {
    private cd;
    constructor(filterService: FilterService, localization: LocalizationService, cd: ChangeDetectorRef);
    protected localizationChange(): void;
    /**
     * @hidden
     */
    messageFor(token: string): string;
    /**
     * @hidden
     */
    get columnLabel(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<BooleanFilterCellComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BooleanFilterCellComponent, "kendo-treelist-boolean-filter-cell", never, {}, {}, never, never, true, never>;
}
