/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { FilterService } from '../filter.service';
import { DateFilterComponent } from '../date-filter.component';
import * as i0 from "@angular/core";
/**
 * Represents a date-filter cell component.
 * Use this component to filter date values in the TreeList.
 * See the article about the [built-in filter components](slug:filter_row_treelist#toc-built-in-filter-row-components).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="OrderDate">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-date-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *     </kendo-treelist-date-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * @remarks
 * Supported children components are: {@link EqualFilterOperatorComponent}, {@link NotEqualFilterOperatorComponent}, {@link AfterEqFilterOperatorComponent}, {@link AfterFilterOperatorComponent}, {@link BeforeEqFilterOperatorComponent}, {@link BeforeFilterOperatorComponent}, {@link IsNullFilterOperatorComponent}, {@link IsNotNullFilterOperatorComponent}.
 */
export declare class DateFilterCellComponent extends DateFilterComponent {
    protected localization: LocalizationService;
    /**
     * Shows or hides the drop-down filter operators.
     * @default true
     */
    showOperators: boolean;
    constructor(filterService: FilterService, localization: LocalizationService);
    /**
     * @hidden
     */
    messageFor(key: string): string;
    /**
     * @hidden
     */
    get columnLabel(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateFilterCellComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateFilterCellComponent, "kendo-treelist-date-filter-cell", never, { "showOperators": { "alias": "showOperators"; "required": false; }; }, {}, never, never, true, never>;
}
