/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, OnInit, OnDestroy } from '@angular/core';
import { DropDownListComponent } from '@progress/kendo-angular-dropdowns';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { ColumnComponent } from '../../columns/column.component';
import * as i0 from "@angular/core";
/**
 * Represents a component that displays filter operators for the TreeList filter row.
 * Use this component to let users select filter operators for a column.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column field="ProductName">
 *     <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *       <input />
 *       <kendo-treelist-filter-cell-operators
 *         [operators]="[{text: 'Equals', value: 'eq'}]">
 *       </kendo-treelist-filter-cell-operators>
 *     </ng-template>
 *   </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class FilterCellOperatorsComponent implements OnInit, OnDestroy {
    protected localization: LocalizationService;
    clearText: string;
    filterClearIcon: SVGIcon;
    /**
     * @hidden
     */
    filterSVGIcon: SVGIcon;
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    /**
     * @hidden
     */
    dropdown: DropDownListComponent;
    /**
     * The filter operators that will be displayed.
     */
    operators: Array<{
        text: string;
        value: string;
    }>;
    /**
     * Determines if the **Clear** button will be displayed.
     * @type {boolean}
     */
    showButton: boolean;
    /**
     * Determines if the list of operators will be displayed.
     * @type {boolean}
     * @default true
     */
    showOperators: boolean;
    /**
     * The selected operator.
     * @type {string}
     */
    value: string;
    /**
     * The TreeList column which the filter operators are associated with.
     */
    column: ColumnComponent;
    /**
     * Fires when the operator is selected.
     * @type {EventEmitter<string>}
     */
    valueChange: EventEmitter<string>;
    /**
     * Fires when the **Clear** button is clicked.
     * @type {EventEmitter<{}>}
     */
    clear: EventEmitter<undefined>;
    private subscription;
    constructor(localization: LocalizationService);
    /**
     * @hidden
     */
    onChange(dataItem: any): void;
    /**
     * @hidden
     */
    clearClick(): boolean;
    /**
     * @hidden
     */
    clearKeydown(args: KeyboardEvent): void;
    /**
     * @hidden
     */
    dropdownKeydown(args: KeyboardEvent): void;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    get columnLabel(): string;
    /**
     * @hidden
     */
    messageFor(token: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterCellOperatorsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterCellOperatorsComponent, "kendo-treelist-filter-cell-operators", never, { "operators": { "alias": "operators"; "required": false; }; "showButton": { "alias": "showButton"; "required": false; }; "showOperators": { "alias": "showOperators"; "required": false; }; "value": { "alias": "value"; "required": false; }; "column": { "alias": "column"; "required": false; }; }, { "valueChange": "valueChange"; "clear": "clear"; }, never, never, true, never>;
}
