/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the filter-cell template for the TreeList.
 * Use this directive to customize the filter row cell for a column.
 * See [custom filter row components](slug:filter_row_treelist#toc-custom-filters).
 *
 * The template context is set to the filter descriptor and provides the following fields:
 * - `column`&mdash;The current column instance. Use as an alias for a template variable with `let-column="column"`.
 * - `filter`&mdash;The filter descriptor.
 * - `cellContext`&mdash;An object used to pass context information to built-in directives.
 *
 * @example
 * ```html
 * <kendo-treelist-column field="name" title="Name">
 *   <ng-template kendoTreeListFilterCellTemplate let-column="column" let-filter="filter" let-cellContext="cellContext">
 *     <kendo-maskedtextbox mask="(999) 000-0000"
 *        [promptPlaceholder]="prompt" [includeLiterals]="true"
 *        (valueChange)="phoneChange($event)"
 *      >
 *      </kendo-maskedtextbox>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class FilterCellTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterCellTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FilterCellTemplateDirective, "[kendoTreeListFilterCellTemplate]", never, {}, {}, never, never, true, never>;
}
