/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { FilterService } from '../filter.service';
import { NumericFilterComponent } from '../numeric-filter.component';
import * as i0 from "@angular/core";
/**
 * Represents a numeric filter cell.
 * Use this component to filter numeric values in the TreeList.
 * See the article about the [built-in filter components](slug:filter_row_treelist#toc-built-in-filter-row-components).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="ProductName" title="Product Name">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-numeric-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *     </kendo-treelist-numeric-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * @remarks
 * Supported children components are: {@link EqualFilterOperatorComponent}, {@link NotEqualFilterOperatorComponent}, {@link GreaterFilterOperatorComponent}, {@link GreaterOrEqualToFilterOperatorComponent}, {@link LessFilterOperatorComponent}, {@link LessOrEqualToFilterOperatorComponent}, {@link IsNullFilterOperatorComponent}, {@link IsNotNullFilterOperatorComponent}.
 */
export declare class NumericFilterCellComponent extends NumericFilterComponent {
    protected localization: LocalizationService;
    /**
     * Sets the delay time (in milliseconds) before the filter value is submitted.
     * A value of `0` means no delay.
     * @default 500
     */
    filterDelay: number;
    /**
     * Shows or hides the drop-down filter operators.
     * @default true
     */
    showOperators: boolean;
    /**
     * The placeholder text for the filter input.
     * @type {string}
     */
    placeholder: string;
    constructor(filterService: FilterService, localization: LocalizationService);
    /**
     * @hidden
     */
    messageFor(key: string): string;
    /**
     * @hidden
     */
    get columnLabel(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumericFilterCellComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumericFilterCellComponent, "kendo-treelist-numeric-filter-cell", never, { "filterDelay": { "alias": "filterDelay"; "required": false; }; "showOperators": { "alias": "showOperators"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; }, {}, never, never, true, never>;
}
