/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Represents the options for the `filterable` setting of the TreeList.
 *
 * The available values are:
 * - `row`&mdash;Displays a filter row in the TreeList.
 * - `menu`&mdash;Displays a filter menu in the TreeList.
 * - `menu, row`&mdash;Displays filter menu with filter row.
 *
 * @example
 * ```html
 * <kendo-treelist filterable="menu, row"></kendo-treelist>
 * ```
 */
export type FilterableSettings = boolean | 'row' | 'menu' | 'menu, row';
/**
 * @hidden
 */
export declare const isFilterable: (settings: FilterableSettings) => boolean;
/**
 * @hidden
 */
export declare const hasFilterMenu: (settings: FilterableSettings) => boolean;
/**
 * @hidden
 */
export declare const hasFilterRow: (settings: FilterableSettings) => boolean;
