/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef } from '@angular/core';
import { CompositeFilterDescriptor } from '@progress/kendo-data-query';
import { RadioButtonComponent } from '@progress/kendo-angular-inputs';
import { FilterService } from '../filter.service';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { BooleanFilterComponent } from '../boolean-filter.component';
import { MenuTabbingService } from './menu-tabbing.service';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI Boolean-filter menu component for Angular TreeList. Use this component to filter boolean fields in the TreeList. [See example](slug:filter_menu_treelist#toc-built-in-filter-menu-components).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="Discontinued" title="Discontinued">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-boolean-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *     </kendo-treelist-boolean-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class BooleanFilterMenuComponent extends BooleanFilterComponent {
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    inputElem: ElementRef;
    /**
     * The current menu filter.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    /**
     * The `FilterService` instance that handles changes in the filter descriptor.
     */
    filterService: FilterService;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    idPrefix: string;
    /**
     * @hidden
     */
    private radioButtons;
    constructor(localization: LocalizationService);
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    radioId(value: any): string;
    /**
     * @hidden
     */
    onChange(value: any, input: RadioButtonComponent): void;
    /**
     * @hidden
     */
    isSelected(radioValue: any): boolean;
    /**
     * @hidden
     */
    onShiftTab(e: Event): void;
    /**
     * @hidden
     */
    get columnLabel(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<BooleanFilterMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BooleanFilterMenuComponent, "kendo-treelist-boolean-filter-menu", never, { "filter": { "alias": "filter"; "required": false; }; "filterService": { "alias": "filterService"; "required": false; }; "menuTabbingService": { "alias": "menuTabbingService"; "required": false; }; }, {}, never, never, true, never>;
}
