/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { CompositeFilterDescriptor, FilterDescriptor } from '@progress/kendo-data-query';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { FilterService } from '../filter.service';
import { DateFilterComponent } from '../date-filter.component';
import { MenuTabbingService } from './menu-tabbing.service';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI date-filter menu component for Angular TreeList. Use this component to filter date fields in the TreeList. [See example](slug:filter_menu_treelist#toc-built-in-filter-menu-components).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="OrderDate" title="Order Date">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-date-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *     </kendo-treelist-date-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * @remarks
 * Supported children components are: {@link EqualFilterOperatorComponent}, {@link NotEqualFilterOperatorComponent}, {@link AfterEqFilterOperatorComponent}, {@link AfterFilterOperatorComponent}, {@link BeforeEqFilterOperatorComponent}, {@link BeforeFilterOperatorComponent}, {@link IsNullFilterOperatorComponent}, {@link IsNotNullFilterOperatorComponent}.
 */
export declare class DateFilterMenuComponent extends DateFilterComponent {
    logicOperators: Array<{
        text: string;
        value: "and" | "or";
    }>;
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    /**
     * The current menu filter.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    /**
     * Determines if the inputs of second criteria are displayed.
     * @type {boolean}
     * @default true
     */
    extra: boolean;
    /**
     * The `FilterService` instance that handles changes in the filter descriptor.
     */
    filterService: FilterService;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    constructor(localization: LocalizationService);
    get firstFilter(): FilterDescriptor;
    get secondFilter(): FilterDescriptor;
    logicChange(value: 'and' | 'or'): void;
    get filterMenuDropDownLabel(): string;
    protected localizationChange(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateFilterMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateFilterMenuComponent, "kendo-treelist-date-filter-menu", never, { "filter": { "alias": "filter"; "required": false; }; "extra": { "alias": "extra"; "required": false; }; "filterService": { "alias": "filterService"; "required": false; }; "menuTabbingService": { "alias": "menuTabbingService"; "required": false; }; }, {}, never, never, true, never>;
}
