/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the filter-menu template for the TreeList filter menu.
 *
 * Use this directive to provide a custom template for the filter menu in a TreeList column
 * ([see example](slug:filter_menu_treelist#toc-custom-filter-menu-components)).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="title" title="Title" [width]="180">
 *  <ng-template kendoTreeListFilterMenuTemplate
 *    let-filter="filter"
 *    let-filterService="filterService">
 *      <my-custom-filter-menu-component
 *          [currentFilter]="filter"
 *          [filterService]="filterService">
 *      </my-custom-filter-menu-component>
 *  </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class FilterMenuTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterMenuTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FilterMenuTemplateDirective, "[kendoTreeListFilterMenuTemplate]", never, {}, {}, never, never, true, never>;
}
