/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { CompositeFilterDescriptor, FilterDescriptor } from '@progress/kendo-data-query';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { FilterService } from '../filter.service';
import { NumericFilterComponent } from '../numeric-filter.component';
import { MenuTabbingService } from './menu-tabbing.service';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI numeric-filter menu component for the TreeList. Use this component to filter numeric values using a filter menu popup.
 * [See example](slug:filter_menu_treelist#toc-built-in-filter-menu-components).
 *
 * @example
 * ```html
 * <kendo-treelist-column field="UnitPrice">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-numeric-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *     </kendo-treelist-numeric-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * @remarks
 * Supported children components are: {@link EqualFilterOperatorComponent}, {@link NotEqualFilterOperatorComponent}, {@link GreaterFilterOperatorComponent}, {@link GreaterOrEqualToFilterOperatorComponent}, {@link LessFilterOperatorComponent}, {@link LessOrEqualToFilterOperatorComponent}, {@link IsNullFilterOperatorComponent}, {@link IsNotNullFilterOperatorComponent}.
 */
export declare class NumericFilterMenuComponent extends NumericFilterComponent {
    logicOperators: Array<{
        text: string;
        value: "and" | "or";
    }>;
    /**
     * @hidden
     */
    get hostClasses(): boolean;
    /**
     * The current menu filter.
     * @type {CompositeFilterDescriptor}
     */
    filter: CompositeFilterDescriptor;
    /**
     * Determines if the inputs of second criteria are displayed.
     * @default true
     */
    extra: boolean;
    /**
     * The `FilterService` instance which is responsible for handling the changes in the filter descriptor.
     */
    filterService: FilterService;
    /**
     * Determines the delay (in milliseconds) before creating a filter descriptor based on the value. A value of 0 indicates no delay.
     * @default 500
     */
    filterDelay: number;
    /**
     * The placeholder text for the filter input.
     * @type {string}
     * @default ''
     */
    placeholder: string;
    /**
     * The placeholder text for the extra filter input. Applies when `extra` is set to `true`.
     * @type {string}
     * @default ''
     */
    extraPlaceholder: string;
    /**
     * @hidden
     */
    menuTabbingService: MenuTabbingService;
    constructor(localization: LocalizationService);
    get firstFilter(): FilterDescriptor;
    get secondFilter(): FilterDescriptor;
    logicChange(value: 'and' | 'or'): void;
    protected localizationChange(): void;
    get filterMenuDropDownLabel(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumericFilterMenuComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumericFilterMenuComponent, "kendo-treelist-numeric-filter-menu", never, { "filter": { "alias": "filter"; "required": false; }; "extra": { "alias": "extra"; "required": false; }; "filterService": { "alias": "filterService"; "required": false; }; "filterDelay": { "alias": "filterDelay"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "extraPlaceholder": { "alias": "extraPlaceholder"; "required": false; }; "menuTabbingService": { "alias": "menuTabbingService"; "required": false; }; }, {}, never, never, true, never>;
}
