/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FilterOperatorBase } from './filter-operator.base';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * Represents the `LessOrEqualTo` (**Is before or equal to**) [date filter operator](slug:filtering_treelist#toc-date-filter) for the TreeList.
 * Use this operator to filter dates that are before or equal to a specific value.
 * [See example](slug:filter_row_treelist#toc-setting-the-default-filter-operator).
 *
 * @example
 * ```html Filter Cell
 * <kendo-treelist-column field="hireDate">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-date-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-treelist-filter-before-eq-operator></kendo-treelist-filter-before-eq-operator>
 *      </kendo-treelist-date-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * ```html Filter Menu
 * <kendo-treelist-column field="hireDate">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-date-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-treelist-filter-before-eq-operator></kendo-treelist-filter-before-eq-operator>
 *     </kendo-treelist-date-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class BeforeEqFilterOperatorComponent extends FilterOperatorBase {
    constructor(localization: LocalizationService);
    /**
     * @hidden
     */
    toJSON(): {
        text: string;
        value: string;
    };
    static ɵfac: i0.ɵɵFactoryDeclaration<BeforeEqFilterOperatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BeforeEqFilterOperatorComponent, "kendo-treelist-filter-before-eq-operator", never, {}, {}, never, never, true, never>;
}
