/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FilterOperatorBase } from './filter-operator.base';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * Represents the `IsNotNull` (**Is not null**) filter operator for the TreeList.
 * Use this operator to filter values that are not null.
 * [See example](slug:filtering_treelist#toc-using-the-built-in-directives).
 * For more information and examples, refer to the article on setting [default filter operators](slug:filter_row_treelist#toc-setting-the-default-filter-operator).
 *
 * @example
 * ```html String Filter Cell
 * <kendo-treelist-column field="name" title="Name">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-string-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-treelist-filter-isnotnull-operator></kendo-treelist-filter-isnotnull-operator>
 *     </kendo-treelist-string-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * ```html Numeric Filter Cell
 * <kendo-treelist-column field="yearsService" title="Years Service">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-numeric-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-treelist-filter-isnotnull-operator></kendo-treelist-filter-isnotnull-operator>
 *     </kendo-treelist-numeric-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * ```html Date Filter Cell
 * <kendo-treelist-column field="hireDate">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-date-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-treelist-filter-isnotnull-operator></kendo-treelist-filter-isnotnull-operator>
 *      </kendo-treelist-date-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 *
 * @example
 * ```html String Filter Menu
 * <kendo-treelist-column field="name" title="Name">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-string-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-treelist-filter-isnotnull-operator></kendo-treelist-filter-isnotnull-operator>
 *     </kendo-treelist-string-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * ```html Numeric Filter Menu
 * <kendo-treelist-column field="yearsService" title="Years Service">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-numeric-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-treelist-filter-isnotnull-operator></kendo-treelist-filter-isnotnull-operator>
 *     </kendo-treelist-numeric-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * ```html Date Filter Menu
 * <kendo-treelist-column field="hireDate">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-date-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-treelist-filter-isnotnull-operator></kendo-treelist-filter-isnotnull-operator>
 *      </kendo-treelist-date-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class IsNotNullFilterOperatorComponent extends FilterOperatorBase {
    constructor(localization: LocalizationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<IsNotNullFilterOperatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IsNotNullFilterOperatorComponent, "kendo-treelist-filter-isnotnull-operator", never, {}, {}, never, never, true, never>;
}
