/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { FilterOperatorBase } from './filter-operator.base';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * Represents the `Less` (**Is less than**) [numeric filter operator](slug:filtering_treelist#toc-numeric-filter) for the TreeList.
 * Use this operator to filter values that are less than a specific value.
 * [See example](slug:filter_row_treelist#toc-setting-the-default-filter-operator).
 *
 * @example
 * ```html Filter Cell
 * <kendo-treelist-column field="yearsService" title="Years Service">
 *   <ng-template kendoTreeListFilterCellTemplate let-filter let-column="column">
 *     <kendo-treelist-numeric-filter-cell
 *       [column]="column"
 *       [filter]="filter">
 *       <kendo-treelist-filter-lt-operator></kendo-treelist-filter-lt-operator>
 *     </kendo-treelist-numeric-filter-cell>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 * ```html Filter Menu
 * <kendo-treelist-column field="yearsService" title="Years Service">
 *   <ng-template kendoTreeListFilterMenuTemplate let-filter let-column="column" let-filterService="filterService">
 *     <kendo-treelist-numeric-filter-menu
 *       [column]="column"
 *       [filter]="filter"
 *       [filterService]="filterService">
 *       <kendo-treelist-filter-lt-operator></kendo-treelist-filter-lt-operator>
 *     </kendo-treelist-numeric-filter-menu>
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class LessFilterOperatorComponent extends FilterOperatorBase {
    constructor(localization: LocalizationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<LessFilterOperatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LessFilterOperatorComponent, "kendo-treelist-filter-lt-operator", never, {}, {}, never, never, true, never>;
}
