/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NavigationCell } from './navigation-cell.interface';
/**
 * Contains the metadata for a focusable TreeList row. Focusable rows include headers, group headers and footers, and data rows.
 */
export interface NavigationRow {
    /**
     * @hidden
     */
    uid: number;
    /**
     * The logical index of the focusable row. The row index is absolute and does not change with paging. Header rows are included, starting at index 0.
     */
    index: number;
    /**
     * The data item index for this row.
     */
    dataRowIndex: number;
    /**
     * A flag that indicates if this is a new row.
     */
    isNew: boolean;
    /**
     * The data item for this row.
     */
    dataItem: any;
    /**
     * An array of focusable cells associated with this row.
     */
    cells: NavigationCell[];
}
