/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PDFService } from './pdf.service';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import * as i0 from "@angular/core";
/**
 * Represents the `export-to-PDF` toolbar tool of the TreeList.
 * Apply this directive to any `kendo-toolbar-button` element inside a
 * ToolbarComponent.
 *
 * When you click the toolbar button that contains the directive, the
 * [`pdfExport`]({% slug api_treelist_treelistcomponent %}#toc-pdfexport) event
 * fires ([see example]({% slug pdfexport_treelist %})).
 *
 * @example
 * ```html
 * <kendo-treelist>
 *     <kendo-toolbar>
 *         <kendo-toolbar-button text="PDF Export" kendoTreeListPDFTool></kendo-toolbar-button>
 *     </kendo-toolbar>
 *     <kendo-treelist-pdf fileName="TreeList.pdf">
 *     </kendo-treelist-pdf>
 * </kendo-treelist>
 * ```
 * @remarks
 * Applied to: {@link ToolBarButtonComponent}
 */
export declare class PDFCommandToolbarDirective {
    private pdfService;
    private host;
    private clickSub;
    constructor(pdfService: PDFService, host: ToolBarButtonComponent);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onClick(e: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PDFCommandToolbarDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PDFCommandToolbarDirective, "[kendoTreeListPDFTool]", never, {}, {}, never, never, true, never>;
}
