/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 as Renderer, NgZone } from '@angular/core';
import { Button } from '@progress/kendo-angular-buttons';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { PDFService } from './pdf.service';
import * as i0 from "@angular/core";
/**
 * Represents the `export-to-PDF` command of the TreeList.
 * Apply this directive to any `button` element inside a
 * [`ToolbarTemplate`](slug:toolbartemplate_treelist).
 * When you click a button that contains the directive, the
 * [`pdfExport`]({% slug api_treelist_treelistcomponent %}#toc-pdfexport) event
 * fires ([see example]({% slug pdfexport_treelist %})).
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <ng-template kendoTreeListToolbarTemplate>
 *     <button kendoTreeListPDFCommand>Export to PDF</button>
 *   </ng-template>
 *   <kendo-treelist-pdf fileName="TreeList.pdf"></kendo-treelist-pdf>
 * </kendo-treelist>
 * ```
 */
export declare class PDFCommandDirective extends Button {
    private pdfService;
    /**
     * @hidden
     */
    onClick(e: any): void;
    /**
     * @hidden
     */
    get pdfClass(): boolean;
    constructor(pdfService: PDFService, element: ElementRef, renderer: Renderer, localization: LocalizationService, ngZone: NgZone);
    static ɵfac: i0.ɵɵFactoryDeclaration<PDFCommandDirective, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PDFCommandDirective, "[kendoTreeListPDFCommand]", never, {}, {}, never, ["*"], true, never>;
}
