/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { PDFExportTemplateDirective } from '@progress/kendo-angular-pdf-export';
import * as i0 from "@angular/core";
/**
 * Represents the PDF page template of the TreeList. Use this directive to customize the PDF pages.
 * To define a page template, nest an `<ng-template>` tag with the `kendoTreeListPDFTemplate` directive inside `<kendo-treelist-pdf>`.
 *
 * The template context provides the following fields:
 * - `pageNumber`&mdash;Defines PDF page number.
 * - `totalPages`&mdash;Defines the total number of PDF pages.
 *
 * @example
 * ```html
 * <kendo-treelist-pdf fileName="Files.pdf" ...>
 *   <ng-template
 *     kendoTreeListPDFTemplate
 *     let-pageNum="pageNum"
 *     let-totalPages="totalPages">
 *     <div style="position: absolute; top: 5px; left: 5px;">
 *       Page {{ pageNum }} of {{ totalPages }}
 *     </div>
 *   </ng-template>
 * </kendo-treelist-pdf>
 * ```
 */
export declare class PDFTemplateDirective extends PDFExportTemplateDirective {
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<PDFTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<PDFTemplateDirective, "[kendoTreeListPDFTemplate]", never, {}, {}, never, never, true, never>;
}
