/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the column cell template of the TreeList ([more information and example]({% slug templates_columns_treelist %}#toc-cell-template)).
 * Use this directive to customize the content of the cells. To define the cell template, nest an `<ng-template>` tag with the `kendoTreeListCellTemplate` directive inside a `<kendo-treelist-column>` tag.
 *
 * The template context is set to the current data item and provides the following fields:
 * - `columnIndex`&mdash;The current column index. Use as an alias for a template variable with `let-columnIndex="columnIndex"`.
 * - `column`&mdash;The current column instance. Use as an alias for a template variable with `let-column="column"`.
 * - `dataItem`&mdash;The current data item. Represents the default context for any template variable using `let-x` syntax, for example, `let-dataItem`.
 * - `cellContext`&mdash;An object for passing context information to built-in directives.
 * - `hasChildren`&mdash;Specifies if the item has children.
 * - `isExpanded`&mdash;Specifies if the item is expanded.
 * - `level`&mdash;The hierarchy level of the item.
 * - `loading`&mdash;Specifies if the item children are currently loading.
 * - `rowIndex`&mdash;The current row index. Use it as an alias for a template variable with `let-rowIndex="rowIndex"`.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <kendo-treelist-column field="ProductName">
 *     <ng-template kendoTreeListCellTemplate let-dataItem let-rowIndex="rowIndex" let-column="column">
 *       Data Row: {{rowIndex}}
 *     </ng-template>
 *   </kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class CellTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<CellTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CellTemplateDirective, "[kendoTreeListCellTemplate]", never, {}, {}, never, never, true, never>;
}
