/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI TreeListSpacer component for Angular.
 * Use this component to add extra white space between Pager inner elements or to customize the spacer width.
 * You can also use it in any flex container within the TreeList. [See example](slug:toolbartemplate_treelist#toc-defining-the-spacing-between-toolbar-elements).
 *
 * @example
 * ```html
 * <kendo-treelist [data]="data" [fetchChildren]="fetchChildren" [hasChildren]="hasChildren">
 *   <ng-template kendoTreeListToolbarTemplate>
 *     <kendo-treelist-spacer></kendo-treelist-spacer>
 *       <button type="button" kendoTreeListExcelCommand [svgIcon]="fileExcelIcon"> Export to Excel </button>
 *     <kendo-treelist-spacer></kendo-treelist-spacer>
 *   </ng-template>
 *   <kendo-treelist-column field="ProductName" title="Product Name"></kendo-treelist-column>
 * </kendo-treelist>
 * ```
 */
export declare class TreeListSpacerComponent {
    hostClass: boolean;
    get sizedClass(): boolean;
    get flexBasisStyle(): string;
    /**
     * Specifies the width of the TreeListSpacer.
     * Accepts string values for the [CSS `flex-basis` property](https://developer.mozilla.org/en-US/docs/Web/CSS/flex-basis).
     *
     * If not set, the TreeListSpacer takes all available space.
     */
    width: string;
    static ɵfac: i0.ɵɵFactoryDeclaration<TreeListSpacerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TreeListSpacerComponent, "kendo-treelist-spacer", never, { "width": { "alias": "width"; "required": false; }; }, {}, never, never, true, never>;
}
