/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the column footer cell template of the TreeList ([more information and example]({% slug templates_columns_treelist %}#toc-footer-template)).
 * Use this directive to customize the table footer cell for the column.
 * To define a footer template, nest an `<ng-template>` tag with the `kendoTreeListFooterTemplate` directive inside the `<kendo-treelist-column>` tag.
 *
 * The template context is set to the aggregate values and provides the following fields:
 * - `aggregates`&mdash;The aggregates for the level items.
 * - `column`&mdash;Defines an instance of the [`ColumnComponent`]({% slug api_treelist_columncomponent %}) option.
 * - `columnIndex`&mdash;Defines the current column index.
 * - `field`&mdash;The name of the column field, if set.
 * - `items`&mdash;The data items on this level.
 * - `parentItem`&mdash;The parent data item; `null` for root level items.
 *
 * @example
 * ```html
 * <kendo-treelist-column field="name">
 *   <ng-template kendoTreeListFooterTemplate let-aggregates="aggregates">
 *     {{ aggregates.name.count }}
 *   </ng-template>
 * </kendo-treelist-column>
 * ```
 */
export declare class FooterTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<FooterTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FooterTemplateDirective, "[kendoTreeListFooterTemplate]", never, {}, {}, never, never, true, never>;
}
