/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Represents the no-records template of the TreeList ([see example](slug:norecordtemplate_treelist)). Use this directive to customize the
 * appearance of the item that is displayed when no data is present. To define the no-records template,
 * nest an `<ng-template>` tag with the `kendoTreeListNoRecordsTemplate` directive inside `<kendo-treelist>`.
 *
 * When the locked columns of the TreeList are in use, the template is displayed in the non-locked part of the content.
 *
 * @example
 * ```html
 * <kendo-treelist ... >
 *   <kendo-treelist-column field="name"></kendo-treelist-column>
 *   <ng-template kendoTreeListNoRecordsTemplate>
 *     No data loaded.
 *   </ng-template>
 * </kendo-treelist>
 * ```
 */
export declare class NoRecordsTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<NoRecordsTemplateDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NoRecordsTemplateDirective, "[kendoTreeListNoRecordsTemplate]", never, {}, {}, never, never, true, never>;
}
