/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef } from '@angular/core';
import { ContextService } from '../../common/provider.service';
import * as i0 from "@angular/core";
/**
 * A directive for toolbar elements that need to be part of TreeList keyboard navigation.
 * Use this directive to make toolbar elements focusable and accessible with the keyboard.
 *
 * @example
 * ```html
 * <kendo-treelist>
 *     <kendo-toolbar>
 *         <button kendoTreeListToolbarFocusable>Custom Button</button>
 *         <button kendoTreeListCancelCommand>Cancel</button>
 *         <button kendoTreeListEditCommand>Edit</button>
 *     </kendo-toolbar>
 * </kendo-treelist>
 * ```
 */
export declare class TreeListToolbarFocusableDirective {
    private host;
    private ctx;
    /**
     * @hidden
     */
    get element(): HTMLElement;
    /**
     * @hidden
     */
    get toolbarPosition(): any;
    constructor(host: ElementRef, ctx: ContextService);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TreeListToolbarFocusableDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TreeListToolbarFocusableDirective, "        [kendoTreeListToolbarFocusable],        [kendoTreeListAddCommand],        [kendoTreeListCancelCommand],        [kendoTreeListEditCommand],        [kendoTreeListRemoveCommand],        [kendoTreeListSaveCommand],        [kendoTreeListExcelCommand],        [kendoTreeListPDFCommand]    ", never, {}, {}, never, never, true, never>;
}
