/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import { OptionChangesService } from '../../common/option-changes.service';
import * as i0 from "@angular/core";
/**
 * Represents the toolbar template of the TreeList ([see example](slug:toolbartemplate_treelist)).
 *
 * The template context has the following field:
 * - `position`&mdash;The position at which the toolbar template is rendered. The possible values are `top`, `bottom`, and `both`.
 *
 * @example
 * ```html
 * <kendo-treelist ...>
 *   <ng-template kendoTreeListToolbarTemplate>
 *     <button kendoTreeListExcelCommand>Export to Excel</button>
 *   </ng-template>
 * </kendo-treelist>
 * ```
 */
export declare class ToolbarTemplateDirective {
    templateRef: TemplateRef<any>;
    private optionChanges;
    _position: 'top' | 'bottom' | 'both';
    /**
     * Sets the position of the toolbar. The value can be `top`, `bottom`, or `both`.
     * Controls whether the toolbar appears above, below, or on both sides of the TreeList. [See example.](slug:toolbartemplate_treelist#toc-setting-the-toolbar-position)
     * @default 'top'
     */
    set position(position: 'top' | 'bottom' | 'both');
    get position(): 'top' | 'bottom' | 'both';
    constructor(templateRef: TemplateRef<any>, optionChanges: OptionChangesService);
    static ɵfac: i0.ɵɵFactoryDeclaration<ToolbarTemplateDirective, [{ optional: true; }, null]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ToolbarTemplateDirective, "[kendoTreeListToolbarTemplate]", never, { "position": { "alias": "position"; "required": false; }; }, {}, never, never, true, never>;
}
