/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The arguments for the `rowReorder` event.
 */
export interface RowReorderEvent {
    /**
     * The rows that are currently dragged and the data associated with them.
     */
    draggedRows: DragRow[];
    /**
     * The row over which the dragged rows are dropped.
     */
    dropTargetRow?: DragRow;
    /**
     * The drop position of the dragged row.
     */
    dropPosition: DropPosition;
}
/**
 * Represents a reorderable data row with an associated data item.
 */
export interface DragRow {
    /**
     * The row data item.
     */
    dataItem: any;
    /**
     * The data row index.
     */
    rowIndex: number;
    /**
     * The row HTML element.
     */
    element: HTMLElement;
}
/**
 * Specifies the drop position for row reordering.
 */
export type DropPosition = 'before' | 'after' | 'over' | 'forbidden';
