/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import type { TreeListComponent } from '../treelist.component';
import { ColumnBase } from '../columns/column-base';
/**
 * The items specified with the [`SelectionChangeEvent`](slug:api_treelist_treelistcomponent#toc-selectionchange).
 */
export interface SelectionChangeItem {
    /**
     * The changed selection dataItem.
     */
    dataItem: any;
    /**
     * The changed selection column. Available only in `cell` selection mode.
     */
    column?: ColumnBase;
    /**
     * The changed selection column index. Available only in `cell` selection mode.
     */
    columnIndex?: number;
}
/**
 * Arguments for the TreeList `selectionChange` event.
 */
export declare class SelectionChangeEvent {
    /**
     * Specifies how the selection was changed.
     */
    action: 'select' | 'add' | 'remove';
    /**
     * Specifies which items were changed.
     */
    items: SelectionChangeItem[];
    /**
     * The TreeList component that triggered the event.
     */
    sender: TreeListComponent;
    /**
     * @hidden
     */
    constructor(action: any, items: SelectionChangeItem[]);
}
