/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from "@angular/core";
import * as i1 from "./treelist.component";
import * as i2 from "./rendering/toolbar/toolbar-template.directive";
import * as i3 from "./rendering/toolbar/toolbar.component";
import * as i4 from "./rendering/common/spacer.component";
import * as i5 from "./localization/custom-messages.component";
import * as i6 from "./editing-directives/template-editing.directive";
import * as i7 from "./editing-directives/reactive-editing.directive";
import * as i8 from "./editing-directives/in-cell-editing.directive";
import * as i9 from "./binding-directives/hierarchy-binding.directive";
import * as i10 from "./binding-directives/flat-binding.directive";
import * as i11 from "./expand-state/expandable.directive";
import * as i12 from "./selection/selectable.directive";
import * as i13 from "./rendering/toolbar/toolbar-focusable.directive";
import * as i14 from "./columns/column.component";
import * as i15 from "./columns/column-group.component";
import * as i16 from "./navigation/logical-cell.directive";
import * as i17 from "./navigation/logical-row.directive";
import * as i18 from "./navigation/focusable.directive";
import * as i19 from "./rendering/common/col-group.component";
import * as i20 from "./layout/resizable.directive";
import * as i21 from "@progress/kendo-angular-common";
import * as i22 from "./rendering/common/field-accessor.pipe";
import * as i23 from "./columns/span-column.component";
import * as i24 from "./rendering/common/loading.component";
import * as i25 from "./filtering/cell/filter-cell-operators.component";
import * as i26 from "./columns/checkbox-column.component";
import * as i27 from "./columns/rowreorder-column.component";
import * as i28 from "./columns/command-column.component";
import * as i29 from "./rendering/cell-template.directive";
import * as i30 from "./rendering/cell.component";
import * as i31 from "./rendering/no-records-template.directive";
import * as i32 from "./editing/edit-template.directive";
import * as i33 from "./editing/edit-command.directive";
import * as i34 from "./editing/cancel-command.directive";
import * as i35 from "./editing/save-command.directive";
import * as i36 from "./editing/remove-command.directive";
import * as i37 from "./editing/add-command.directive";
import * as i38 from "./editing/add-command-tool.directive";
import * as i39 from "./rendering/footer-template.directive";
import * as i40 from "./rendering/header/header.component";
import * as i41 from "./rendering/header/header-template.directive";
import * as i42 from "./column-resizing/column-handle.directive";
import * as i43 from "./filtering/filter-row.component";
import * as i44 from "./filtering/cell/filter-cell.component";
import * as i45 from "./filtering/cell/filter-cell-template.directive";
import * as i46 from "./filtering/cell/string-filter-cell.component";
import * as i47 from "./filtering/cell/numeric-filter-cell.component";
import * as i48 from "./filtering/cell/autocomplete-filter-cell.component";
import * as i49 from "./filtering/cell/boolean-filter-cell.component";
import * as i50 from "./filtering/cell/filter-cell-host.directive";
import * as i51 from "./filtering/cell/filter-cell-wrapper.component";
import * as i52 from "./filtering/cell/date-filter-cell.component";
import * as i53 from "./filtering/operators/contains-filter-operator.component";
import * as i54 from "./filtering/operators/not-contains-filter-operator.component";
import * as i55 from "./filtering/operators/ends-with-filter-operator.component";
import * as i56 from "./filtering/operators/eq-filter-operator.component";
import * as i57 from "./filtering/operators/is-empty-filter-operator.component";
import * as i58 from "./filtering/operators/is-not-empty-filter-operator.component";
import * as i59 from "./filtering/operators/is-not-null-filter-operator.component";
import * as i60 from "./filtering/operators/isnull-filter-operator.component";
import * as i61 from "./filtering/operators/neq-filter-operator.component";
import * as i62 from "./filtering/operators/starts-with-filter-operator.component";
import * as i63 from "./filtering/operators/gt-filter-operator.component";
import * as i64 from "./filtering/operators/gte-filter-operator.component";
import * as i65 from "./filtering/operators/lt-filter-operator.component";
import * as i66 from "./filtering/operators/lte-filter-operator.component";
import * as i67 from "./filtering/operators/after-filter-operator.component";
import * as i68 from "./filtering/operators/after-eq-filter-operator.component";
import * as i69 from "./filtering/operators/before-eq-filter-operator.component";
import * as i70 from "./filtering/operators/before-filter-operator.component";
import * as i71 from "./filtering/filter-input.directive";
import * as i72 from "./filtering/menu/filter-menu.component";
import * as i73 from "./filtering/menu/filter-menu-container.component";
import * as i74 from "./filtering/menu/filter-menu-input-wrapper.component";
import * as i75 from "./filtering/menu/string-filter-menu-input.component";
import * as i76 from "./filtering/menu/string-filter-menu.component";
import * as i77 from "./filtering/menu/filter-menu-template.directive";
import * as i78 from "./filtering/menu/numeric-filter-menu.component";
import * as i79 from "./filtering/menu/numeric-filter-menu-input.component";
import * as i80 from "./filtering/menu/date-filter-menu-input.component";
import * as i81 from "./filtering/menu/date-filter-menu.component";
import * as i82 from "./filtering/menu/filter-menu-host.directive";
import * as i83 from "./filtering/menu/boolean-filter-menu.component";
import * as i84 from "./filtering/menu/filter-radio-button.directive";
import * as i85 from "./column-menu/column-chooser.component";
import * as i86 from "./column-menu/column-menu-chooser.component";
import * as i87 from "./column-menu/column-menu-filter.component";
import * as i88 from "./column-menu/column-menu-item.component";
import * as i89 from "./column-menu/column-menu-item-content-template.directive";
import * as i90 from "./column-menu/column-menu-sort.component";
import * as i91 from "./column-menu/column-menu.component";
import * as i92 from "./column-menu/column-menu-lock.component";
import * as i93 from "./column-menu/column-menu-template.directive";
import * as i94 from "./column-menu/column-menu-item.directive";
import * as i95 from "./excel/excel.component";
import * as i96 from "./excel/excel-command.directive";
import * as i97 from "./excel/excel-command-tool.directive";
import * as i98 from "@progress/kendo-angular-excel-export";
import * as i99 from "./pdf/pdf.component";
import * as i100 from "./pdf/pdf-margin.component";
import * as i101 from "./pdf/pdf-command.directive";
import * as i102 from "./pdf/pdf-template.directive";
import * as i103 from "./pdf/pdf-command-tool.directive";
import * as i104 from "@progress/kendo-angular-toolbar";
import * as i105 from "@progress/kendo-angular-pager";
import * as i106 from "./column-resizing/table.directive";
/**
 * Represents the [`NgModule`](link:site.data.urls.angular['ngmoduleapi']) definition for the TreeList component.
 * Use this module to enable TreeList features in your application.
 *
 * @example
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { TreeListModule } from '@progress/kendo-angular-treelist';
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *   declarations: [AppComponent],
 *   imports: [BrowserModule, TreeListModule],
 *   bootstrap: [AppComponent]
 * })
 * export class AppModule {}
 * ```
 */
export declare class TreeListModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<TreeListModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<TreeListModule, never, [typeof i1.TreeListComponent, typeof i2.ToolbarTemplateDirective, typeof i3.ToolbarComponent, typeof i4.TreeListSpacerComponent, typeof i5.CustomMessagesComponent, typeof i6.TemplateEditingDirective, typeof i7.ReactiveEditingDirective, typeof i8.InCellEditingDirective, typeof i9.HierarchyBindingDirective, typeof i10.FlatBindingDirective, typeof i11.ExpandableDirective, typeof i12.SelectableDirective, typeof i13.TreeListToolbarFocusableDirective, typeof i14.ColumnComponent, typeof i15.ColumnGroupComponent, typeof i16.LogicalCellDirective, typeof i17.LogicalRowDirective, typeof i18.FocusableDirective, typeof i19.ColGroupComponent, typeof i20.ResizableContainerDirective, typeof i21.TemplateContextDirective, typeof i22.FieldAccessorPipe, typeof i23.SpanColumnComponent, typeof i24.LoadingComponent, typeof i25.FilterCellOperatorsComponent, typeof i26.CheckboxColumnComponent, typeof i27.RowReorderColumnComponent, typeof i28.CommandColumnComponent, typeof i29.CellTemplateDirective, typeof i30.CellComponent, typeof i31.NoRecordsTemplateDirective, typeof i32.EditTemplateDirective, typeof i33.EditCommandDirective, typeof i34.CancelCommandDirective, typeof i35.SaveCommandDirective, typeof i36.RemoveCommandDirective, typeof i37.AddCommandDirective, typeof i38.AddCommandToolbarDirective, typeof i39.FooterTemplateDirective, typeof i40.HeaderComponent, typeof i41.HeaderTemplateDirective, typeof i42.ColumnHandleDirective, typeof i43.FilterRowComponent, typeof i44.FilterCellComponent, typeof i45.FilterCellTemplateDirective, typeof i46.StringFilterCellComponent, typeof i47.NumericFilterCellComponent, typeof i48.AutoCompleteFilterCellComponent, typeof i49.BooleanFilterCellComponent, typeof i50.FilterCellHostDirective, typeof i51.FilterCellWrapperComponent, typeof i52.DateFilterCellComponent, typeof i25.FilterCellOperatorsComponent, typeof i53.ContainsFilterOperatorComponent, typeof i54.DoesNotContainFilterOperatorComponent, typeof i55.EndsWithFilterOperatorComponent, typeof i56.EqualFilterOperatorComponent, typeof i57.IsEmptyFilterOperatorComponent, typeof i58.IsNotEmptyFilterOperatorComponent, typeof i59.IsNotNullFilterOperatorComponent, typeof i60.IsNullFilterOperatorComponent, typeof i61.NotEqualFilterOperatorComponent, typeof i62.StartsWithFilterOperatorComponent, typeof i63.GreaterFilterOperatorComponent, typeof i64.GreaterOrEqualToFilterOperatorComponent, typeof i65.LessFilterOperatorComponent, typeof i66.LessOrEqualToFilterOperatorComponent, typeof i67.AfterFilterOperatorComponent, typeof i68.AfterEqFilterOperatorComponent, typeof i69.BeforeEqFilterOperatorComponent, typeof i70.BeforeFilterOperatorComponent, typeof i71.FilterInputDirective, typeof i14.ColumnComponent, typeof i15.ColumnGroupComponent, typeof i16.LogicalCellDirective, typeof i17.LogicalRowDirective, typeof i18.FocusableDirective, typeof i19.ColGroupComponent, typeof i20.ResizableContainerDirective, typeof i21.TemplateContextDirective, typeof i22.FieldAccessorPipe, typeof i23.SpanColumnComponent, typeof i24.LoadingComponent, typeof i25.FilterCellOperatorsComponent, typeof i26.CheckboxColumnComponent, typeof i27.RowReorderColumnComponent, typeof i72.FilterMenuComponent, typeof i73.FilterMenuContainerComponent, typeof i74.FilterMenuInputWrapperComponent, typeof i75.StringFilterMenuInputComponent, typeof i76.StringFilterMenuComponent, typeof i77.FilterMenuTemplateDirective, typeof i78.NumericFilterMenuComponent, typeof i79.NumericFilterMenuInputComponent, typeof i80.DateFilterMenuInputComponent, typeof i81.DateFilterMenuComponent, typeof i82.FilterMenuHostDirective, typeof i83.BooleanFilterMenuComponent, typeof i84.BooleanFilterRadioButtonDirective, typeof i85.ColumnChooserComponent, typeof i86.ColumnMenuChooserComponent, typeof i87.ColumnMenuFilterComponent, typeof i88.ColumnMenuItemComponent, typeof i89.ColumnMenuItemContentTemplateDirective, typeof i90.ColumnMenuSortComponent, typeof i91.ColumnMenuComponent, typeof i92.ColumnMenuLockComponent, typeof i93.ColumnMenuTemplateDirective, typeof i94.ColumnMenuItemDirective, typeof i95.ExcelComponent, typeof i96.ExcelCommandDirective, typeof i97.ExcelCommandToolbarDirective, typeof i98.ColumnComponent, typeof i98.ColumnGroupComponent, typeof i98.FooterTemplateDirective, typeof i98.GroupFooterTemplateDirective, typeof i98.GroupHeaderColumnTemplateDirective, typeof i98.GroupHeaderTemplateDirective, typeof i99.PDFComponent, typeof i100.PDFMarginComponent, typeof i101.PDFCommandDirective, typeof i102.PDFTemplateDirective, typeof i103.PDFCommandToolbarDirective, typeof i104.ToolBarComponent, typeof i104.ToolbarCustomMessagesComponent, typeof i104.ToolBarButtonComponent, typeof i104.ToolBarButtonGroupComponent, typeof i104.ToolBarDropDownButtonComponent, typeof i104.ToolBarSeparatorComponent, typeof i104.ToolBarSpacerComponent, typeof i104.ToolBarSplitButtonComponent, typeof i104.ToolBarToolComponent, typeof i105.CustomMessagesComponent, typeof i105.PagerFocusableDirective, typeof i105.PagerInfoComponent, typeof i105.PagerInputComponent, typeof i105.PagerNextButtonsComponent, typeof i105.PagerNumericButtonsComponent, typeof i105.PagerPageSizesComponent, typeof i105.PagerPrevButtonsComponent, typeof i105.PagerTemplateDirective, typeof i105.PagerComponent, typeof i105.PagerSpacerComponent, typeof i106.TableDirective], [typeof i1.TreeListComponent, typeof i2.ToolbarTemplateDirective, typeof i3.ToolbarComponent, typeof i4.TreeListSpacerComponent, typeof i5.CustomMessagesComponent, typeof i6.TemplateEditingDirective, typeof i7.ReactiveEditingDirective, typeof i8.InCellEditingDirective, typeof i9.HierarchyBindingDirective, typeof i10.FlatBindingDirective, typeof i11.ExpandableDirective, typeof i12.SelectableDirective, typeof i13.TreeListToolbarFocusableDirective, typeof i14.ColumnComponent, typeof i15.ColumnGroupComponent, typeof i16.LogicalCellDirective, typeof i17.LogicalRowDirective, typeof i18.FocusableDirective, typeof i19.ColGroupComponent, typeof i20.ResizableContainerDirective, typeof i21.TemplateContextDirective, typeof i22.FieldAccessorPipe, typeof i23.SpanColumnComponent, typeof i24.LoadingComponent, typeof i25.FilterCellOperatorsComponent, typeof i26.CheckboxColumnComponent, typeof i27.RowReorderColumnComponent, typeof i28.CommandColumnComponent, typeof i29.CellTemplateDirective, typeof i30.CellComponent, typeof i31.NoRecordsTemplateDirective, typeof i32.EditTemplateDirective, typeof i33.EditCommandDirective, typeof i34.CancelCommandDirective, typeof i35.SaveCommandDirective, typeof i36.RemoveCommandDirective, typeof i37.AddCommandDirective, typeof i38.AddCommandToolbarDirective, typeof i39.FooterTemplateDirective, typeof i40.HeaderComponent, typeof i41.HeaderTemplateDirective, typeof i42.ColumnHandleDirective, typeof i43.FilterRowComponent, typeof i44.FilterCellComponent, typeof i45.FilterCellTemplateDirective, typeof i46.StringFilterCellComponent, typeof i47.NumericFilterCellComponent, typeof i48.AutoCompleteFilterCellComponent, typeof i49.BooleanFilterCellComponent, typeof i50.FilterCellHostDirective, typeof i51.FilterCellWrapperComponent, typeof i52.DateFilterCellComponent, typeof i25.FilterCellOperatorsComponent, typeof i53.ContainsFilterOperatorComponent, typeof i54.DoesNotContainFilterOperatorComponent, typeof i55.EndsWithFilterOperatorComponent, typeof i56.EqualFilterOperatorComponent, typeof i57.IsEmptyFilterOperatorComponent, typeof i58.IsNotEmptyFilterOperatorComponent, typeof i59.IsNotNullFilterOperatorComponent, typeof i60.IsNullFilterOperatorComponent, typeof i61.NotEqualFilterOperatorComponent, typeof i62.StartsWithFilterOperatorComponent, typeof i63.GreaterFilterOperatorComponent, typeof i64.GreaterOrEqualToFilterOperatorComponent, typeof i65.LessFilterOperatorComponent, typeof i66.LessOrEqualToFilterOperatorComponent, typeof i67.AfterFilterOperatorComponent, typeof i68.AfterEqFilterOperatorComponent, typeof i69.BeforeEqFilterOperatorComponent, typeof i70.BeforeFilterOperatorComponent, typeof i71.FilterInputDirective, typeof i14.ColumnComponent, typeof i15.ColumnGroupComponent, typeof i16.LogicalCellDirective, typeof i17.LogicalRowDirective, typeof i18.FocusableDirective, typeof i19.ColGroupComponent, typeof i20.ResizableContainerDirective, typeof i21.TemplateContextDirective, typeof i22.FieldAccessorPipe, typeof i23.SpanColumnComponent, typeof i24.LoadingComponent, typeof i25.FilterCellOperatorsComponent, typeof i26.CheckboxColumnComponent, typeof i27.RowReorderColumnComponent, typeof i72.FilterMenuComponent, typeof i73.FilterMenuContainerComponent, typeof i74.FilterMenuInputWrapperComponent, typeof i75.StringFilterMenuInputComponent, typeof i76.StringFilterMenuComponent, typeof i77.FilterMenuTemplateDirective, typeof i78.NumericFilterMenuComponent, typeof i79.NumericFilterMenuInputComponent, typeof i80.DateFilterMenuInputComponent, typeof i81.DateFilterMenuComponent, typeof i82.FilterMenuHostDirective, typeof i83.BooleanFilterMenuComponent, typeof i84.BooleanFilterRadioButtonDirective, typeof i85.ColumnChooserComponent, typeof i86.ColumnMenuChooserComponent, typeof i87.ColumnMenuFilterComponent, typeof i88.ColumnMenuItemComponent, typeof i89.ColumnMenuItemContentTemplateDirective, typeof i90.ColumnMenuSortComponent, typeof i91.ColumnMenuComponent, typeof i92.ColumnMenuLockComponent, typeof i93.ColumnMenuTemplateDirective, typeof i94.ColumnMenuItemDirective, typeof i95.ExcelComponent, typeof i96.ExcelCommandDirective, typeof i97.ExcelCommandToolbarDirective, typeof i98.ColumnComponent, typeof i98.ColumnGroupComponent, typeof i98.FooterTemplateDirective, typeof i98.GroupFooterTemplateDirective, typeof i98.GroupHeaderColumnTemplateDirective, typeof i98.GroupHeaderTemplateDirective, typeof i99.PDFComponent, typeof i100.PDFMarginComponent, typeof i101.PDFCommandDirective, typeof i102.PDFTemplateDirective, typeof i103.PDFCommandToolbarDirective, typeof i104.ToolBarComponent, typeof i104.ToolbarCustomMessagesComponent, typeof i104.ToolBarButtonComponent, typeof i104.ToolBarButtonGroupComponent, typeof i104.ToolBarDropDownButtonComponent, typeof i104.ToolBarSeparatorComponent, typeof i104.ToolBarSpacerComponent, typeof i104.ToolBarSplitButtonComponent, typeof i104.ToolBarToolComponent, typeof i105.CustomMessagesComponent, typeof i105.PagerFocusableDirective, typeof i105.PagerInfoComponent, typeof i105.PagerInputComponent, typeof i105.PagerNextButtonsComponent, typeof i105.PagerNumericButtonsComponent, typeof i105.PagerPageSizesComponent, typeof i105.PagerPrevButtonsComponent, typeof i105.PagerTemplateDirective, typeof i105.PagerComponent, typeof i105.PagerSpacerComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<TreeListModule>;
}
